/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 08506
 |         NATIONAL YOUTH SURVEY [UNITED STATES]: WAVE III, 1978
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\08506-0001-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE v5ffffff  1='(1) Male' 2='(2) Female' ;
  VALUE v6ffffff  1='(1) Anglo' 2='(2) Black' 3='(3) Hispanic' 4='(4) American Indian'
                  5='(5) Asian' 6='(6) Other' ;
  VALUE v11fffff  1='(1) Mother/father' 2='(2) Mother only' 3='(3) Father only'
                  4='(4) Mother/stepfather' 5='(5) Father/stepmother' 6='(6) Spouse'
                  7='(7) Roommate' 8='(8) Boy/girl friend' 9='(9) Alone'
                  10='(10) Moth/oth rel' 11='(11) Moth/oth non-rel' 12='(12) Fath/oth rel'
                  13='(13) Fath/oth non-rel' 14='(14) Moth/fath/rel'
                  15='(15) Moth/fath/non-rel' 16='(16) Relatives' 17='(17) Other' ;
  VALUE v12fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v13fffff  13='(13) Winter' 14='(14) Spring' 15='(15) Summer' 16='(16) Fall' ;
  VALUE v15fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v16fffff  13='(13) Winter' 14='(14) Spring' 15='(15) Summer' 16='(16) Fall' ;
  VALUE v18fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v19fffff  13='(13) Winter' 14='(14) Spring' 15='(15) Summer' 16='(16) Fall' ;
  VALUE v21fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v22fffff  13='(13) Winter' 14='(14) Spring' 15='(15) Summer' 16='(16) Fall' ;
  VALUE v24fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v25fffff  13='(13) Winter' 14='(14) Spring' 15='(15) Summer' 16='(16) Fall' ;
  VALUE v27fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v28fffff  13='(13) Winter' 14='(14) Spring' 15='(15) Summer' 16='(16) Fall' ;
  VALUE v30fffff  13='(13) Winter' 14='(14) Spring' 15='(15) Summer' 16='(16) Fall' ;
  VALUE v32fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v33fffff  13='(13) Winter' 14='(14) Spring' 15='(15) Summer' 16='(16) Fall' ;
  VALUE v35fffff  13='(13) Winter' 14='(14) Spring' 15='(15) Summer' 16='(16) Fall' ;
  VALUE v37fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v38fffff  13='(13) Winter' 14='(14) Spring' 15='(15) Summer' 16='(16) Fall' ;
  VALUE v40fffff  13='(13) Winter' 14='(14) Spring' 15='(15) Summer' 16='(16) Fall' ;
  VALUE v43fffff  1='(1) NIMH' 2='(2) LEAA' ;
  VALUE v47fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v48fffff  13='(13) Winter' 14='(14) Spring' 15='(15) Summer' 16='(16) Fall' ;
  VALUE v50fffff  13='(13) Winter' 14='(14) Spring' 15='(15) Summer' 16='(16) Fall' ;
  VALUE v52fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v53fffff  13='(13) Winter' 14='(14) Spring' 15='(15) Summer' 16='(16) Fall' ;
  VALUE v55fffff  13='(13) Winter' 14='(14) Spring' 15='(15) Summer' 16='(16) Fall' ;
  VALUE v57fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v58fffff  13='(13) Winter' 14='(14) Spring' 15='(15) Summer' 16='(16) Fall' ;
  VALUE v60fffff  13='(13) Winter' 14='(14) Spring' 15='(15) Summer' 16='(16) Fall' ;
  VALUE v62fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v63fffff  13='(13) Winter' 14='(14) Spring' 15='(15) Summer' 16='(16) Fall' ;
  VALUE v65fffff  13='(13) Winter' 14='(14) Spring' 15='(15) Summer' 16='(16) Fall' ;
  VALUE v67fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v68fffff  13='(13) Winter' 14='(14) Spring' 15='(15) Summer' 16='(16) Fall' ;
  VALUE v70fffff  13='(13) Winter' 14='(14) Spring' 15='(15) Summer' 16='(16) Fall' ;
  VALUE v72fffff  1='(1) No coding problems' 2='(2) Coding problems' ;
  VALUE v73fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v74fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v75fffff  1='(1) Not important' 2='(2) Not too important'
                  3='(3) Somewhat important' 4='(4) Pretty important'
                  5='(5) Very important' ;
  VALUE v76fffff  0='(0) < once a week' ;
  VALUE v77fffff  0='(0) < once a week' ;
  VALUE v78fffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v79fffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v80fffff  1='(1) Not important' 2='(2) Not too important'
                  3='(3) Somewhat important' 4='(4) Pretty important'
                  5='(5) Very important' ;
  VALUE v81fffff  0='(0) < once a week' ;
  VALUE v82fffff  1='(1) Not important' 2='(2) Not too important'
                  3='(3) Somewhat important' 4='(4) Pretty important'
                  5='(5) Very important' ;
  VALUE v83fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v84fffff  18='(18) Not in school' 19='(19) Adult education' 20='(20) GED program'
                  21='(21) Business/sec school' 22='(22) Voc/tech school' 23='(23) Other' ;
  VALUE v85fffff  1='(1) Mostly F''s' 2='(2) Mostly D''s' 3='(3) Mostly C''s'
                  4='(4) Mostly B''s' 5='(5) Mostly A''s' ;
  VALUE v86fffff  0='(0) < once a week' ;
  VALUE v87fffff  0='(0) < once a week' ;
  VALUE v88fffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v89fffff  1='(1) Not important' 2='(2) Not too important'
                  3='(3) Somewhat important' 4='(4) Pretty important'
                  5='(5) Very important' ;
  VALUE v91fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v92fffff  1='(1) Contact sport' 2='(2) Non-contact sport' 3='(3) Combination' ;
  VALUE v93fffff  1='(1) Not important' 2='(2) Not too important'
                  3='(3) Somewhat important' 4='(4) Pretty important'
                  5='(5) Very important' ;
  VALUE v94fffff  0='(0) < once a week' ;
  VALUE v95fffff  0='(0) < once a week' ;
  VALUE v96fffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v97fffff  1='(1) Not important' 2='(2) Not too important'
                  3='(3) Somewhat important' 4='(4) Pretty important'
                  5='(5) Very important' ;
  VALUE v98fffff  1='(1) No' 2='(2) Yes' ;
  VALUE v99fffff  1='(1) Serv service' 2='(2) Rec/hobby/voc' 3='(3) Student govt'
                  4='(4) Journal' 5='(5) Drama/art/culture' 6='(6) Cheer/Pom-Pom/Pep'
                  7='(7) R.O.T.C.' 8='(8) Other' 9='(9) Comb of activ'
                  10='(10) Academic clubs' ;
  VALUE v100ffff  1='(1) Not important' 2='(2) Not too important'
                  3='(3) Somewhat important' 4='(4) Pretty important'
                  5='(5) Very important' ;
  VALUE v101ffff  0='(0) < once a week' ;
  VALUE v102ffff  0='(0) < once a week' ;
  VALUE v103ffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v104ffff  1='(1) Not important' 2='(2) Not too important'
                  3='(3) Somewhat important' 4='(4) Pretty important'
                  5='(5) Very important' ;
  VALUE v105ffff  1='(1) Athlete' 2='(2) Activ member' 3='(3) Social type'
                  4='(4) Good student' 5='(5) Average student' 6='(6) None' 7='(7) Other' ;
  VALUE v106ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v107ffff  1='(1) Relig/church' 2='(2) Service clubs' 3='(3) Rec/athletic clubs'
                  4='(4) Other' 5='(5) Comb of activities' 6='(6) Drama/art/culture' ;
  VALUE v108ffff  1='(1) Not important' 2='(2) Not too important'
                  3='(3) Somewhat important' 4='(4) Pretty important'
                  5='(5) Very important' ;
  VALUE v109ffff  0='(0) < once a week' ;
  VALUE v110ffff  0='(0) < once a week' ;
  VALUE v111ffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v112ffff  1='(1) Not important' 2='(2) Not too important'
                  3='(3) Somewhat important' 4='(4) Pretty important'
                  5='(5) Very important' ;
  VALUE v113ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v114ffff  1='(1) Not important at all' 2='(2) Not too important'
                  3='(3) Somewhat important' 4='(4) Pretty important'
                  5='(5) Very important' ;
  VALUE v115ffff  1='(1) Part-time' 2='(2) Full-time' ;
  VALUE v116ffff  1='(1) Seasonal/episodic' 2='(2) Year round' ;
  VALUE v117ffff  1='(1) Informal jobs' 2='(2) Un/semi skilled' 3='(3) Skilled manual'
                  4='(4) Clerical/tech/sales' 5='(5) Exec/prof/admin' ;
  VALUE v119ffff  1='(1) Other' 2='(2) Exp for future' 3='(3) Out of house' 4='(4) Freedom'
                  5='(5) Money' 6='(6) Enjoyment/fun' 7='(7) Help someone' 8='(8) Boredom'
                  9='(9) For experience' ;
  VALUE v120ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v121ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v122ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v123ffff  1='(1) Not important' 2='(2) Not too important'
                  3='(3) Somewhat important' 4='(4) Pretty important'
                  5='(5) Very important' ;
  VALUE v124ffff  0='(0) < once a week' ;
  VALUE v125ffff  0='(0) < once a week' ;
  VALUE v126ffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v127ffff  1='(1) Not important' 2='(2) Not too important'
                  3='(3) Somewhat important' 4='(4) Pretty important'
                  5='(5) Very important' ;
  VALUE v128ffff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE v129ffff  1='(1) Never' 2='(2) Several times a yr' 3='(3) Once or twice a mo'
                  4='(4) Once a wk' 5='(5) Several times a wk' ;
  VALUE v130ffff  1='(1) Not important' 2='(2) Not too important'
                  3='(3) Somewhat important' 4='(4) Pretty important'
                  5='(5) Very important' ;
  VALUE v131ffff  1='(1) Not important at' 3='(3) Somewhat important'
                  5='(5) Very important' ;
  VALUE v132ffff  1='(1) Not well at all' 3='(3) O.K.' 5='(5) Very well' ;
  VALUE v133ffff  1='(1) Not important' 3='(3) Somewhat important' 5='(5) Very important' ;
  VALUE v134ffff  1='(1) Not well at all' 3='(3) O.K.' 5='(5) Very well' ;
  VALUE v135ffff  1='(1) Not important' 3='(3) Somewhat important' 5='(5) Very important' ;
  VALUE v136ffff  1='(1) Not well at all' 3='(3) O.K.' 5='(5) Very well' ;
  VALUE v137ffff  1='(1) Not important' 3='(3) Somewhat important' 5='(5) Very important' ;
  VALUE v138ffff  1='(1) Not well at all' 3='(3) O.K.' 5='(5) Very well' ;
  VALUE v139ffff  1='(1) Not important' 3='(3) Somewhat important' 5='(5) Very important' ;
  VALUE v140ffff  1='(1) Not well at all' 3='(3) O.K.' 5='(5) Very well' ;
  VALUE v141ffff  1='(1) Not important' 3='(3) Somewhat important' 5='(5) Very important' ;
  VALUE v142ffff  1='(1) Not well at all' 3='(3) O.K.' 5='(5) Very well' ;
  VALUE v143ffff  1='(1) Not important' 3='(3) Somewhat important' 5='(5) Very important' ;
  VALUE v144ffff  1='(1) Not well at all' 3='(3) O.K.' 5='(5) Very well' ;
  VALUE v145ffff  1='(1) Not important' 3='(3) Somewhat important' 5='(5) Very important' ;
  VALUE v146ffff  1='(1) Not well at all' 3='(3) O.K.' 5='(5) Very well' ;
  VALUE v147ffff  1='(1) Not important' 3='(3) Somewhat important' 5='(5) Very important' ;
  VALUE v148ffff  1='(1) Not well at all' 3='(3) O.K.' 5='(5) Very well' ;
  VALUE v149ffff  1='(1) Not important' 3='(3) Somewhat important' 5='(5) Very important' ;
  VALUE v150ffff  1='(1) Not well at all' 3='(3) O.K.' 5='(5) Very well' ;
  VALUE v151ffff  1='(1) Not important' 3='(3) Somewhat important' 5='(5) Very important' ;
  VALUE v152ffff  1='(1) Not well at all' 3='(3) O.K.' 5='(5) Very well' ;
  VALUE v153ffff  1='(1) Not important' 3='(3) Somewhat important' 5='(5) Very important' ;
  VALUE v154ffff  1='(1) Not well at all' 3='(3) O.K.' 5='(5) Very well' ;
  VALUE v155ffff  1='(1) Not important' 3='(3) Somewhat important' 5='(5) Very important' ;
  VALUE v156ffff  1='(1) Not well at all' 3='(3) O.K.' 5='(5) Very well' ;
  VALUE v157ffff  1='(1) Not important' 3='(3) Somewhat important' 5='(5) Very important' ;
  VALUE v158ffff  1='(1) Not well at all' 3='(3) O.K.' 5='(5) Very well' ;
  VALUE v159ffff  1='(1) Not important' 3='(3) Somewhat important' 5='(5) Very important' ;
  VALUE v160ffff  1='(1) Not important' 3='(3) Somewhat important' 5='(5) Very important' ;
  VALUE v161ffff  1='(1) Not important' 3='(3) Somewhat important' 5='(5) Very important' ;
  VALUE v162ffff  1='(1) Not important' 3='(3) Somewhat important' 5='(5) Very important' ;
  VALUE v163ffff  1='(1) Yes' 2='(2) Don''t know' 3='(3) Haven''t thought' ;
  VALUE v164ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v165ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v166ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v167ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v168ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v169ffff  1='(1) Yes' 2='(2) Don''t know' 3='(3) Haven''t thought' ;
  VALUE v170ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v171ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v172ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v173ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v174ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v175ffff  1='(1) Yes' 2='(2) Don''t know' 3='(3) Haven''t thought' ;
  VALUE v176ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v177ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v178ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v179ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v180ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v181ffff  1='(1) Yes' 2='(2) Don''t know' 3='(3) Haven''t thought' ;
  VALUE v182ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v183ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v184ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v185ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v186ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v187ffff  1='(1) Poor' 2='(2) Fair' 3='(3) Good' ;
  VALUE v188ffff  1='(1) Poor' 2='(2) Fair' 3='(3) Good' ;
  VALUE v189ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v190ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v191ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v192ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v193ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v194ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v195ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v196ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v197ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v198ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v199ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v200ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v201ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v202ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v203ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v204ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v205ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v206ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v207ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v208ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v209ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v210ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v211ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v212ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v213ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v214ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v215ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v216ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v217ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v218ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v219ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v220ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v221ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v222ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v223ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v224ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v225ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v226ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v227ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v228ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v229ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v230ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v231ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v232ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v233ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v234ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v235ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v236ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v237ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v238ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v239ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v240ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v241ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v242ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v243ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v244ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v245ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v246ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v247ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v248ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v249ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v250ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v251ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v252ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v253ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v254ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v255ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v256ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v257ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v258ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v259ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v260ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v261ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v262ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v263ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v264ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v265ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v266ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v267ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v268ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v269ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v270ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v271ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v272ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v273ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v274ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v275ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v276ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v277ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v278ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v279ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v280ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v281ffff  1='(1) Strongly approve' 2='(2) Approve' 3='(3) Neither' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE v282ffff  1='(1) Almost never' 2='(2) Sometimes' 3='(3) Often' 4='(4) Almost always' ;
  VALUE v283ffff  1='(1) Almost never' 2='(2) Sometimes' 3='(3) Often' 4='(4) Almost always' ;
  VALUE v284ffff  1='(1) Almost never' 2='(2) Sometimes' 3='(3) Often' 4='(4) Almost always' ;
  VALUE v285ffff  1='(1) Almost never' 2='(2) Sometimes' 3='(3) Often' 4='(4) Almost always' ;
  VALUE v286ffff  1='(1) Almost never' 2='(2) Sometimes' 3='(3) Often' 4='(4) Almost always' ;
  VALUE v287ffff  1='(1) Almost never' 2='(2) Sometimes' 3='(3) Often' 4='(4) Almost always' ;
  VALUE v288ffff  1='(1) Almost never' 2='(2) Sometimes' 3='(3) Often' 4='(4) Almost always' ;
  VALUE v289ffff  1='(1) Almost never' 2='(2) Sometimes' 3='(3) Often' 4='(4) Almost always' ;
  VALUE v290ffff  1='(1) Almost never' 2='(2) Sometimes' 3='(3) Often' 4='(4) Almost always' ;
  VALUE v291ffff  1='(1) Almost never' 2='(2) Sometimes' 3='(3) Often' 4='(4) Almost always' ;
  VALUE v292ffff  1='(1) Almost never' 2='(2) Sometimes' 3='(3) Often' 4='(4) Almost always' ;
  VALUE v293ffff  1='(1) Almost never' 2='(2) Sometimes' 3='(3) Often' 4='(4) Almost always' ;
  VALUE v294ffff  1='(1) Not wrong at all' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE v295ffff  1='(1) Not wrong at all' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE v296ffff  1='(1) Not wrong at all' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE v297ffff  1='(1) Not wrong at all' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE v298ffff  1='(1) Not wrong at all' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE v299ffff  1='(1) Not wrong at all' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE v300ffff  1='(1) Not wrong at all' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE v301ffff  1='(1) Not wrong at all' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE v302ffff  1='(1) Not wrong at all' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE v303ffff  1='(1) Not wrong at all' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE v304ffff  1='(1) Not wrong at all' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE v305ffff  1='(1) Not wrong at all' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE v306ffff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE v307ffff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE v308ffff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE v309ffff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE v310ffff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE v311ffff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE v312ffff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE v313ffff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE v314ffff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE v315ffff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE v316ffff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE v317ffff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE v318ffff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE v319ffff  1='(1) No' 2='(2) Don''t know' 3='(3) Yes' ;
  VALUE v320ffff  1='(1) No' 2='(2) Don''t know' 3='(3) Yes' ;
  VALUE v321ffff  1='(1) No' 2='(2) Don''t know' 3='(3) Yes' ;
  VALUE v322ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v323ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v324ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v325ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v326ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v327ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v328ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v329ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v330ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v331ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v332ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v333ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v334ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v335ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v336ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v337ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v338ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v339ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v340ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v341ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v342ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v343ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v344ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v345ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v346ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v347ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v348ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v349ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v350ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v351ffff  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Neither' 4='(4) Agree'
                  5='(5) Strongly agree' ;
  VALUE v352ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Several times' 4='(4) Often' ;
  VALUE v353ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Several times' 4='(4) Often' ;
  VALUE v354ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Several times' 4='(4) Often' ;
  VALUE v355ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Several times' 4='(4) Often' ;
  VALUE v356ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Several times' 4='(4) Often' ;
  VALUE v357ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Several times' 4='(4) Often' ;
  VALUE v358ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Several times' 4='(4) Often' ;
  VALUE v359ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Several times' 4='(4) Often' ;
  VALUE v360ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Several times' 4='(4) Often' ;
  VALUE v361ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Several times' 4='(4) Often' ;
  VALUE v362ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Several times' 4='(4) Often' ;
  VALUE v363ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Several times' 4='(4) Often' ;
  VALUE v364ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Several times' 4='(4) Often' ;
  VALUE v365ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Several times' 4='(4) Often' ;
  VALUE v367ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v369ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v371ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v373ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v375ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v377ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v379ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v381ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v383ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v385ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v387ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v389ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v391ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v393ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v395ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v397ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v399ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v401ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v403ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v405ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v407ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v409ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v411ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v413ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v415ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v417ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v419ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v421ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v423ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v425ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v427ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v429ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v431ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v433ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v435ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v437ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v439ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v441ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v443ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v445ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v447ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v449ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v451ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v453ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v455ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v457ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v459ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v461ffff  1='(1) No' 2='(2) Yes' 3='(3) Don''t know' ;
  VALUE v462ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v463ffff  1='(1) Yes' ;
  VALUE v465ffff  0='(0) Less than 1 can' 1='(1) 1 can' 2='(2) 2 cans' 3='(3) Three cans'
                  4='(4) 4-5 cans' 5='(5) 6-pack or more' 6='(6) Other' ;
  VALUE v466ffff  1='(1) Relieve phys pain' 2='(2) Relieve boredom'
                  3='(3) Relieve tension' 4='(4) Pleasure' 5='(5) To be different'
                  6='(6) To be accepted' 7='(7) To be relaxed' 8='(8) Appear grown-up'
                  9='(9) Increase self-aware' 10='(10) Get through day' 11='(11) Curiosity'
                  12='(12) Special occasions' 13='(13) Family encourage' 14='(14) Other' ;
  VALUE v467ffff  1='(1) Not effective' 2='(2) Effective' ;
  VALUE v468ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v469ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v470ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v471ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v472ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v473ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v474ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v475ffff  1='(1) Disliked taste' 2='(2) Bad phys effects'
                  3='(3) Bad emotion effect' 4='(4) Felt it was wrong'
                  5='(5) Friends'' pressure' 6='(6) Trouble w/parents'
                  7='(7) Fearful of addict' 8='(8) Not available' 9='(9) Lost effects'
                  10='(10) Didn''t need it' 11='(11) Other' ;
  VALUE v477ffff  1='(1) No' 2='(2) Yes' 3='(3) Don''t know' ;
  VALUE v478ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v479ffff  1='(1) Yes' ;
  VALUE v481ffff  0='(0) Less than 1 glass' 1='(1) 1 glass' 2='(2) 2 glasses'
                  3='(3) Three glasses' 4='(4) 4-5 glasses' 5='(5) 6 glasses or more'
                  6='(6) Other' ;
  VALUE v482ffff  1='(1) Relieve phys pain' 2='(2) Relieve boredom'
                  3='(3) Relieve tension' 4='(4) Pleasure' 5='(5) To be different'
                  6='(6) To be accepted' 7='(7) To be relaxed' 8='(8) Appear grown-up'
                  9='(9) Increase self-aware' 10='(10) Get through day' 11='(11) Curiosity'
                  12='(12) Special occasions' 13='(13) Family encourage' 14='(14) Other' ;
  VALUE v483ffff  1='(1) Not effective' 2='(2) Effective' ;
  VALUE v484ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v485ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v486ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v487ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v488ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v489ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v490ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v491ffff  1='(1) Disliked taste' 2='(2) Bad phys effects'
                  3='(3) Bad emotion effect' 4='(4) Felt it was wrong'
                  5='(5) Friends'' pressure' 6='(6) Trouble w/parents'
                  7='(7) Fearful of addict' 8='(8) Not available' 9='(9) Lost effects'
                  10='(10) Didn''t need it' 11='(11) Other' ;
  VALUE v493ffff  1='(1) No' 2='(2) Yes' 3='(3) Don''t know' ;
  VALUE v494ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v495ffff  1='(1) Yes' ;
  VALUE v497ffff  0='(0) Less than 1 glass' 1='(1) 1 glass' 2='(2) 2 glasses'
                  3='(3) Three glasses' 4='(4) 4-5 glasses' 5='(5) 6 glasses or more'
                  6='(6) Other' ;
  VALUE v498ffff  1='(1) Relieve phys pain' 2='(2) Relieve boredom'
                  3='(3) Relieve tension' 4='(4) Pleasure' 5='(5) To be different'
                  6='(6) To be accepted' 7='(7) To be relaxed' 8='(8) Appear grown-up'
                  9='(9) Increase self-aware' 10='(10) Get through day' 11='(11) Curiosity'
                  12='(12) Special occasions' 13='(13) Family encourage' 14='(14) Other' ;
  VALUE v499ffff  1='(1) Not effective' 2='(2) Effective' ;
  VALUE v500ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v501ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v502ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v503ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v504ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v505ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v506ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v507ffff  1='(1) Disliked taste' 2='(2) Bad phys effects'
                  3='(3) Bad emotion effect' 4='(4) Felt it was wrong'
                  5='(5) Friends'' pressure' 6='(6) Trouble w/parents'
                  7='(7) Fearful of addict' 8='(8) Not available' 9='(9) Lost effects'
                  10='(10) Didn''t need it' 11='(11) Other' ;
  VALUE v509ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v510ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v511ffff  1='(1) No' 2='(2) Yes' 3='(3) Don''t know' ;
  VALUE v512ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v513ffff  1='(1) Yes' ;
  VALUE v519ffff  1='(1) Relieve phys pain' 2='(2) Relieve boredom'
                  3='(3) Relieve tension' 4='(4) Pleasure' 5='(5) To be different'
                  6='(6) To be accepted' 7='(7) To be relaxed' 8='(8) Appear grown-up'
                  9='(9) Increase self-aware' 10='(10) Get through day' 11='(11) Curiosity'
                  12='(12) Special occasions' 13='(13) Family encourage' 14='(14) Other' ;
  VALUE v520ffff  1='(1) Not effective' 2='(2) Effective' ;
  VALUE v521ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v522ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v523ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v524ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v525ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v526ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v527ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v528ffff  1='(1) Disliked taste' 2='(2) Bad phys effects'
                  3='(3) Bad emotion effect' 4='(4) Felt it was wrong'
                  5='(5) Friends'' pressure' 6='(6) Trouble w/parents'
                  7='(7) Fearful of addict' 8='(8) Not available' 9='(9) Lost effects'
                  10='(10) Didn''t need it' 11='(11) Other' ;
  VALUE v530ffff  1='(1) No' 2='(2) Yes' 3='(3) Don''t know' ;
  VALUE v531ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v532ffff  1='(1) Yes' ;
  VALUE v534ffff  1='(1) Share joint' 2='(2) 1 joint' 3='(3) 2 joints'
                  4='(4) More than 2 joints' 5='(5) Other' ;
  VALUE v535ffff  1='(1) Relieve phys pain' 2='(2) Relieve boredom'
                  3='(3) Relieve tension' 4='(4) Pleasure' 5='(5) To be different'
                  6='(6) To be accepted' 7='(7) To be relaxed' 8='(8) Appear grown-up'
                  9='(9) Increase self-aware' 10='(10) Get through day' 11='(11) Curiosity'
                  12='(12) Special occasions' 13='(13) Family encourage' 14='(14) Other' ;
  VALUE v536ffff  1='(1) Not effective' 2='(2) Effective' ;
  VALUE v537ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v538ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v539ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v540ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v541ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v542ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v543ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v544ffff  1='(1) Disliked taste' 2='(2) Bad phys effects'
                  3='(3) Bad emotion effect' 4='(4) Felt it was wrong'
                  5='(5) Friends'' pressure' 6='(6) Trouble w/parents'
                  7='(7) Fearful of addict' 8='(8) Not available' 9='(9) Lost effects'
                  10='(10) Didn''t need it' 11='(11) Other' ;
  VALUE v546ffff  1='(1) No' 2='(2) Yes' 3='(3) Don''t know' ;
  VALUE v547ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v548ffff  1='(1) Yes' ;
  VALUE v551ffff  1='(1) Relieve phys pain' 2='(2) Relieve boredom'
                  3='(3) Relieve tension' 4='(4) Pleasure' 5='(5) To be different'
                  6='(6) To be accepted' 7='(7) To be relaxed' 8='(8) Appear grown-up'
                  9='(9) Increase self-aware' 10='(10) Get through day' 11='(11) Curiosity'
                  12='(12) Special occasions' 13='(13) Family encourage' 14='(14) Other' ;
  VALUE v552ffff  1='(1) Not effective' 2='(2) Effective' ;
  VALUE v553ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v554ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v555ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v556ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v557ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v558ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v559ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v560ffff  1='(1) Disliked taste' 2='(2) Bad phys effects'
                  3='(3) Bad emotion effect' 4='(4) Felt it was wrong'
                  5='(5) Friends'' pressure' 6='(6) Trouble w/parents'
                  7='(7) Fearful of addict' 8='(8) Not available' 9='(9) Lost effects'
                  10='(10) Didn''t need it' 11='(11) Other' ;
  VALUE v562ffff  1='(1) No' 2='(2) Yes' 3='(3) Don''t know' ;
  VALUE v563ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v564ffff  1='(1) Yes' ;
  VALUE v566ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v567ffff  1='(1) < prescribed' 2='(2) Amount prescribed' 3='(3) > prescribed' ;
  VALUE v568ffff  1='(1) Relieve phys pain' 2='(2) Relieve boredom'
                  3='(3) Relieve tension' 4='(4) Pleasure' 5='(5) To be different'
                  6='(6) To be accepted' 7='(7) To be relaxed' 8='(8) Appear grown-up'
                  9='(9) Increase self-aware' 10='(10) Get through day' 11='(11) Curiosity'
                  12='(12) Special occasions' 13='(13) Family encourage' 14='(14) Other' ;
  VALUE v569ffff  1='(1) Not effective' 2='(2) Effective' ;
  VALUE v570ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v571ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v572ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v573ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v574ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v575ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v576ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v577ffff  1='(1) Disliked taste' 2='(2) Bad phys effects'
                  3='(3) Bad emotion effect' 4='(4) Felt it was wrong'
                  5='(5) Friends'' pressure' 6='(6) Trouble w/parents'
                  7='(7) Fearful of addict' 8='(8) Not available' 9='(9) Lost effects'
                  10='(10) Didn''t need it' 11='(11) Other' ;
  VALUE v579ffff  1='(1) No' 2='(2) Yes' 3='(3) Don''t know' ;
  VALUE v580ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v581ffff  1='(1) Yes' ;
  VALUE v583ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v584ffff  1='(1) < prescribed' 2='(2) Amount prescribed' 3='(3) > prescribed' ;
  VALUE v585ffff  1='(1) Relieve phys pain' 2='(2) Relieve boredom'
                  3='(3) Relieve tension' 4='(4) Pleasure' 5='(5) To be different'
                  6='(6) To be accepted' 7='(7) To be relaxed' 8='(8) Appear grown-up'
                  9='(9) Increase self-aware' 10='(10) Get through day' 11='(11) Curiosity'
                  12='(12) Special occasions' 13='(13) Family encourage' 14='(14) Other' ;
  VALUE v586ffff  1='(1) Not effective' 2='(2) Effective' ;
  VALUE v587ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v588ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v589ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v590ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v591ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v592ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v593ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v594ffff  1='(1) Disliked taste' 2='(2) Bad phys effects'
                  3='(3) Bad emotion effect' 4='(4) Felt it was wrong'
                  5='(5) Friends'' pressure' 6='(6) Trouble w/parents'
                  7='(7) Fearful of addict' 8='(8) Not available' 9='(9) Lost effects'
                  10='(10) Didn''t need it' 11='(11) Other' ;
  VALUE v596ffff  1='(1) No' 2='(2) Yes' 3='(3) Don''t know' ;
  VALUE v597ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v598ffff  1='(1) Yes' ;
  VALUE v600ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v601ffff  1='(1) < prescribed' 2='(2) Amount prescribed' 3='(3) > prescribed' ;
  VALUE v602ffff  1='(1) Relieve phys pain' 2='(2) Relieve boredom'
                  3='(3) Relieve tension' 4='(4) Pleasure' 5='(5) To be different'
                  6='(6) To be accepted' 7='(7) To be relaxed' 8='(8) Appear grown-up'
                  9='(9) Increase self-aware' 10='(10) Get through day' 11='(11) Curiosity'
                  12='(12) Special occasions' 13='(13) Family encourage' 14='(14) Other' ;
  VALUE v603ffff  1='(1) Not effective' 2='(2) Effective' ;
  VALUE v604ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v605ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v606ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v607ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v608ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v609ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v610ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v611ffff  1='(1) Disliked taste' 2='(2) Bad phys effects'
                  3='(3) Bad emotion effect' 4='(4) Felt it was wrong'
                  5='(5) Friends'' pressure' 6='(6) Trouble w/parents'
                  7='(7) Fearful of addict' 8='(8) Not available' 9='(9) Lost effects'
                  10='(10) Didn''t need it' 11='(11) Other' ;
  VALUE v613ffff  1='(1) No' 2='(2) Yes' 3='(3) Don''t know' ;
  VALUE v614ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v615ffff  1='(1) Yes' ;
  VALUE v617ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v618ffff  1='(1) < prescribed' 2='(2) Amount prescribed' 3='(3) > prescribed' ;
  VALUE v619ffff  1='(1) Relieve phys pain' 2='(2) Relieve boredom'
                  3='(3) Relieve tension' 4='(4) Pleasure' 5='(5) To be different'
                  6='(6) To be accepted' 7='(7) To be relaxed' 8='(8) Appear grown-up'
                  9='(9) Increase self-aware' 10='(10) Get through day' 11='(11) Curiosity'
                  12='(12) Special occasions' 13='(13) Family encourage' 14='(14) Other' ;
  VALUE v620ffff  1='(1) Not effective' 2='(2) Effective' ;
  VALUE v621ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v622ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v623ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v624ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v625ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v626ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v627ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v628ffff  1='(1) Disliked taste' 2='(2) Bad phys effects'
                  3='(3) Bad emotion effect' 4='(4) Felt it was wrong'
                  5='(5) Friends'' pressure' 6='(6) Trouble w/parents'
                  7='(7) Fearful of addict' 8='(8) Not available' 9='(9) Lost effects'
                  10='(10) Didn''t need it' 11='(11) Other' ;
  VALUE v630ffff  1='(1) No' 2='(2) Yes' 3='(3) Don''t know' ;
  VALUE v631ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v632ffff  1='(1) Yes' ;
  VALUE v634ffff  1='(1) Relieve phys pain' 2='(2) Relieve boredom'
                  3='(3) Relieve tension' 4='(4) Pleasure' 5='(5) To be different'
                  6='(6) To be accepted' 7='(7) To be relaxed' 8='(8) Appear grown-up'
                  9='(9) Increase self-aware' 10='(10) Get through day' 11='(11) Curiosity'
                  12='(12) Special occasions' 13='(13) Family encourage' 14='(14) Other' ;
  VALUE v635ffff  1='(1) Not effective' 2='(2) Effective' ;
  VALUE v636ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v637ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v638ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v639ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v640ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v641ffff  1='(1) Disliked taste' 2='(2) Bad phys effects'
                  3='(3) Bad emotion effect' 4='(4) Felt it was wrong'
                  5='(5) Friends'' pressure' 6='(6) Trouble w/parents'
                  7='(7) Fearful of addict' 8='(8) Not available' 9='(9) Lost effects'
                  10='(10) Didn''t need it' 11='(11) Other' ;
  VALUE v643ffff  1='(1) No' 2='(2) Yes' 3='(3) Don''t know' ;
  VALUE v644ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v645ffff  1='(1) Yes' ;
  VALUE v647ffff  0='(0) < 1' 1='(1) 1 line' 2='(2) 2 lines' 3='(3) 3 or more lines' ;
  VALUE v648ffff  1='(1) Relieve phys pain' 2='(2) Relieve boredom'
                  3='(3) Relieve tension' 4='(4) Pleasure' 5='(5) To be different'
                  6='(6) To be accepted' 7='(7) To be relaxed' 8='(8) Appear grown-up'
                  9='(9) Increase self-aware' 10='(10) Get through day' 11='(11) Curiosity'
                  12='(12) Special occasions' 13='(13) Family encourage' 14='(14) Other' ;
  VALUE v649ffff  1='(1) Not effective' 2='(2) Effective' ;
  VALUE v650ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v651ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v652ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v653ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v654ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v655ffff  1='(1) Disliked taste' 2='(2) Bad phys effects'
                  3='(3) Bad emotion effect' 4='(4) Felt it was wrong'
                  5='(5) Friends'' pressure' 6='(6) Trouble w/parents'
                  7='(7) Fearful of addict' 8='(8) Not available' 9='(9) Lost effects'
                  10='(10) Didn''t need it' 11='(11) Other' ;
  VALUE v657ffff  1='(1) No' 2='(2) Yes' 3='(3) Don''t know' ;
  VALUE v658ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v659ffff  1='(1) Yes' ;
  VALUE v661ffff  1='(1) Relieve phys pain' 2='(2) Relieve boredom'
                  3='(3) Relieve tension' 4='(4) Pleasure' 5='(5) To be different'
                  6='(6) To be accepted' 7='(7) To be relaxed' 8='(8) Appear grown-up'
                  9='(9) Increase self-aware' 10='(10) Get through day' 11='(11) Curiosity'
                  12='(12) Special occasions' 13='(13) Family encourage' 14='(14) Other' ;
  VALUE v662ffff  1='(1) Not effective' 2='(2) Effective' ;
  VALUE v663ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v664ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v665ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v666ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v667ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v668ffff  1='(1) Disliked taste' 2='(2) Bad phys effects'
                  3='(3) Bad emotion effect' 4='(4) Felt it was wrong'
                  5='(5) Friends'' pressure' 6='(6) Trouble w/parents'
                  7='(7) Fearful of addict' 8='(8) Not available' 9='(9) Lost effects'
                  10='(10) Didn''t need it' 11='(11) Other' ;
  VALUE v670ffff  1='(1) No' 2='(2) Yes' 3='(3) Don''t know' ;
  VALUE v671ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v672ffff  1='(1) Yes' ;
  VALUE v674ffff  1='(1) With marijuana' 2='(2) Powder' 3='(3) Capsule' ;
  VALUE v675ffff  1='(1) Relieve phys pain' 2='(2) Relieve boredom'
                  3='(3) Relieve tension' 4='(4) Pleasure' 5='(5) To be different'
                  6='(6) To be accepted' 7='(7) To be relaxed' 8='(8) Appear grown-up'
                  9='(9) Increase self-aware' 10='(10) Get through day' 11='(11) Curiosity'
                  12='(12) Special occasions' 13='(13) Family encourage' 14='(14) Other' ;
  VALUE v676ffff  1='(1) Not effective' 2='(2) Effective' ;
  VALUE v677ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v678ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v679ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v680ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v681ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v682ffff  1='(1) Disliked taste' 2='(2) Bad phys effects'
                  3='(3) Bad emotion effect' 4='(4) Felt it was wrong'
                  5='(5) Friends'' pressure' 6='(6) Trouble w/parents'
                  7='(7) Fearful of addict' 8='(8) Not available' 9='(9) Lost effects'
                  10='(10) Didn''t need it' 11='(11) Other' ;
  VALUE v683ffff  1='(1) THC' 2='(2) Quaaludes' 3='(3) Cough medicine' 4='(4) Robitussin'
                  5='(5) Sominex' 6='(6) Sudafed' 7='(7) No-doze' 8='(8) Demerol'
                  9='(9) Weight-control pills' 10='(10) Coricidin' 11='(11) Mushrooms'
                  12='(12) MDA' 13='(13) Pam' ;
  VALUE v685ffff  1='(1) No' 2='(2) Yes' 3='(3) Don''t know' ;
  VALUE v686ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 mos'
                  4='(4) Once a mo' 5='(5) Once every 2-3 wks' 6='(6) Once a wk'
                  7='(7) 2-3 times a wk' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE v687ffff  1='(1) Yes' ;
  VALUE v689ffff  1='(1) Relieve phys pain' 2='(2) Relieve boredom'
                  3='(3) Relieve tension' 4='(4) Pleasure' 5='(5) To be different'
                  6='(6) To be accepted' 7='(7) To be relaxed' 8='(8) Appear grown-up'
                  9='(9) Increase self-aware' 10='(10) Get through day' 11='(11) Curiosity'
                  12='(12) Special occasions' 13='(13) Family encourage' 14='(14) Other' ;
  VALUE v690ffff  1='(1) Not effective' 2='(2) Effective' ;
  VALUE v691ffff  1='(1) Friends' 2='(2) Pharm/Drug Store' 3='(3) Neighbors' 4='(4) Friends'
                  5='(5) Physician' 6='(6) Seller/pusher' 7='(7) Store' ;
  VALUE v692ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v693ffff  1='(1) Disliked taste' 2='(2) Bad phys effects'
                  3='(3) Bad emotion effect' 4='(4) Felt it was wrong'
                  5='(5) Friends'' pressure' 6='(6) Trouble w/parents'
                  7='(7) Fearful of addict' 8='(8) Not available' 9='(9) Lost effects'
                  10='(10) Didn''t need it' 11='(11) Other' ;
  VALUE v697ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE v698ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE v699ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE v700ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE v701ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE v702ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE v703ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE v704ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE v705ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE v706ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE v707ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE v708ffff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE v709ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v710ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v711ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v712ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v713ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v714ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v715ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v716ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v717ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v718ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v719ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v720ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v721ffff  1='(1) Yes' ;
  VALUE v722ffff  1='(1) Yes' ;
  VALUE v723ffff  1='(1) Yes' ;
  VALUE v724ffff  1='(1) Yes' ;
  VALUE v725ffff  1='(1) Yes' ;
  VALUE v726ffff  1='(1) Yes' ;
  VALUE v727ffff  1='(1) Yes' ;
  VALUE v728ffff  1='(1) Yes' ;
  VALUE v729ffff  1='(1) Yes' ;
  VALUE v730ffff  1='(1) Yes' ;
  VALUE v731ffff  1='(1) Yes' ;
  VALUE v732ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v733ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v744ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v751ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v752ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v753ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v754ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v755ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v756ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v757ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v758ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v759ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v761ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v762ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v763ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v764ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v765ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v766ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v767ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v768ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v769ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v772ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v773ffff  1='(1) Drugs' ;
  VALUE v774ffff  1='(1) Sex' ;
  VALUE v778ffff  1='(1) Friends' ;
  VALUE v779ffff  1='(1) Drugs/alcohol' ;
  VALUE v780ffff  1='(1) Family' ;
  VALUE v781ffff  1='(1) Activities' ;
  VALUE v782ffff  1='(1) School' ;
  VALUE v783ffff  1='(1) Other' ;
  VALUE v784ffff  1='(1) Good understanding' 2='(2) Poor understanding'
                  3='(3) Fair understanding' ;
  VALUE v785ffff  1='(1) Not anxious' 2='(2) Somewhat anxious' 3='(3) Very anxious' ;
  VALUE v786ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v787ffff  1='(1) Very low' 2='(2) Below average' 3='(3) Average'
                  4='(4) Above average' 5='(5) Very high' ;
  VALUE v788ffff  1='(1) Diff w/language' ;
  VALUE v789ffff  1='(1) Diff w/questions' ;
  VALUE v790ffff  1='(1) Interruptions' ;
  VALUE v791ffff  1='(1) Temp Breakoff' ;
  VALUE v792ffff  1='(1) Breakoff' ;
  VALUE v793ffff  1='(1) Other' ;
  VALUE v794ffff  1='(1) Relaxed' 2='(2) Tense' 3='(3) Other' ;
  VALUE v795ffff  1='(1) No' 2='(2) Yes' ;
  VALUE v796ffff  0='(0) Resp not in SMSA' 1='(1) Resp in SMSA' ;
  VALUE v797ffff  1='(1) SMSA' 2='(2) Urbanized area' 3='(3) SMSA/urban area'
                  4='(4) Other inc place' 5='(5) Not incorporated' ;
  VALUE v798ffff  0='(0) Under 200' 1='(1) 200-499' 2='(2) 500-999' 3='(3) 1,000-1,499'
                  4='(4) -1,500-1,999' 5='(5) 2,000-2,499' 6='(6) 2,500-4,999'
                  7='(7) 5,000-9,999' 8='(8) 10,000-19,999' 9='(9) 20,000-24,999'
                  10='(10) 25,000-49,999' 11='(11) 50,000-99,999' 12='(12) 100,000-249,999'
                  13='(13) 250,000-499,999' 14='(14) 500,000-999,999'
                  15='(15) 1,000,000 or >' ;
  VALUE v799ffff  1='(1) Urban' 2='(2) Suburban' 3='(3) Rural' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=1636;
INPUT
        CASEID 1629-1636        V5 1-2                  V6 3-4
        V10 5-6                 V11 7-8                 V12 9-10
        V13 11-12               V14 13-14               V15 15-16
        V16 17-18               V17 19-20               V18 21-22
        V19 23-24               V20 25-26               V21 27-28
        V22 29-30               V23 31-32               V24 33-34
        V25 35-36               V26 37-38               V27 39-40
        V28 41-42               V29 43-44               V30 45-46
        V31 47-48               V32 49-50               V33 51-52
        V34 53-54               V35 55-56               V36 57-58
        V37 59-60               V38 61-62               V39 63-64
        V40 65-66               V41 67-68               V42 69-70
        V43 71                  V44 72-75               V45 76
        V46 77-79               V47 80-81               V48 82-83
        V49 84-85               V50 86-87               V51 88-89
        V52 90-91               V53 92-93               V54 94-95
        V55 96-97               V56 98-99               V57 100-101
        V58 102-103             V59 104-105             V60 106-107
        V61 108-109             V62 110-111             V63 112-113
        V64 114-115             V65 116-117             V66 118-119
        V67 120-121             V68 122-123             V69 124-125
        V70 126-127             V71 128-129             V72 130-131
        V73 132-133             V74 134-135             V75 136-137
        V76 138-139             V77 140-141             V78 142-143
        V79 144-145             V80 146-147             V81 148-149
        V82 150-151             V83 152-153             V84 154-155
        V85 156-157             V86 158-159             V87 160-161
        V88 162-163             V89 164-165             V90 166-167
        V91 168-169             V92 170-171             V93 172-173
        V94 174-175             V95 176-177             V96 178-179
        V97 180-181             V98 182-183             V99 184-185
        V100 186-187            V101 188-189            V102 190-191
        V103 192-193            V104 194-195            V105 196-197
        V106 198-199            V107 200-201            V108 202-203
        V109 204-205            V110 206-207            V111 208-209
        V112 210-211            V113 212-213            V114 214-215
        V115 216-217            V116 218-219            V117 220-221
        V118 222-223            V119 224-225            V120 226-227
        V121 228-229            V122 230-231            V123 232-233
        V124 234-235            V125 236-237            V126 238-239
        V127 240-241            V128 242-243            V129 244-245
        V130 246-247            V131 248-249            V132 250-251
        V133 252-253            V134 254-255            V135 256-257
        V136 258-259            V137 260-261            V138 262-263
        V139 264-265            V140 266-267            V141 268-269
        V142 270-271            V143 272-273            V144 274-275
        V145 276-277            V146 278-279            V147 280-281
        V148 282-283            V149 284-285            V150 286-287
        V151 288-289            V152 290-291            V153 292-293
        V154 294-295            V155 296-297            V156 298-299
        V157 300-301            V158 302-303            V159 304-305
        V160 306-307            V161 308-309            V162 310-311
        V163 312-313            V164 314-315            V165 316-317
        V166 318-319            V167 320-321            V168 322-323
        V169 324-325            V170 326-327            V171 328-329
        V172 330-331            V173 332-333            V174 334-335
        V175 336-337            V176 338-339            V177 340-341
        V178 342-343            V179 344-345            V180 346-347
        V181 348-349            V182 350-351            V183 352-353
        V184 354-355            V185 356-357            V186 358-359
        V187 360-361            V188 362-363            V189 364-365
        V190 366-367            V191 368-369            V192 370-371
        V193 372-373            V194 374-375            V195 376-377
        V196 378-379            V197 380-381            V198 382-383
        V199 384-385            V200 386-387            V201 388-389
        V202 390-391            V203 392-393            V204 394-395
        V205 396-397            V206 398-399            V207 400-401
        V208 402-403            V209 404-405            V210 406-407
        V211 408-409            V212 410-411            V213 412-413
        V214 414-415            V215 416-417            V216 418-419
        V217 420-421            V218 422-423            V219 424-425
        V220 426-427            V221 428-429            V222 430-431
        V223 432-433            V224 434-435            V225 436-437
        V226 438-439            V227 440-441            V228 442-443
        V229 444-445            V230 446-447            V231 448-449
        V232 450-451            V233 452-453            V234 454-455
        V235 456-457            V236 458-459            V237 460-461
        V238 462-463            V239 464-465            V240 466-467
        V241 468-469            V242 470-471            V243 472-473
        V244 474-475            V245 476-477            V246 478-479
        V247 480-481            V248 482-483            V249 484-485
        V250 486-487            V251 488-489            V252 490-491
        V253 492-493            V254 494-495            V255 496-497
        V256 498-499            V257 500-501            V258 502-503
        V259 504-505            V260 506-507            V261 508-509
        V262 510-511            V263 512-513            V264 514-515
        V265 516-517            V266 518-519            V267 520-521
        V268 522-523            V269 524-525            V270 526-527
        V271 528-529            V272 530-531            V273 532-533
        V274 534-535            V275 536-537            V276 538-539
        V277 540-541            V278 542-543            V279 544-545
        V280 546-547            V281 548-549            V282 550-551
        V283 552-553            V284 554-555            V285 556-557
        V286 558-559            V287 560-561            V288 562-563
        V289 564-565            V290 566-567            V291 568-569
        V292 570-571            V293 572-573            V294 574-575
        V295 576-577            V296 578-579            V297 580-581
        V298 582-583            V299 584-585            V300 586-587
        V301 588-589            V302 590-591            V303 592-593
        V304 594-595            V305 596-597            V306 598-599
        V307 600-601            V308 602-603            V309 604-605
        V310 606-607            V311 608-609            V312 610-611
        V313 612-613            V314 614-615            V315 616-617
        V316 618-619            V317 620-621            V318 622-623
        V319 624-625            V320 626-627            V321 628-629
        V322 630-631            V323 632-633            V324 634-635
        V325 636-637            V326 638-639            V327 640-641
        V328 642-643            V329 644-645            V330 646-647
        V331 648-649            V332 650-651            V333 652-653
        V334 654-655            V335 656-657            V336 658-659
        V337 660-661            V338 662-663            V339 664-665
        V340 666-667            V341 668-669            V342 670-671
        V343 672-673            V344 674-675            V345 676-677
        V346 678-679            V347 680-681            V348 682-683
        V349 684-685            V350 686-687            V351 688-689
        V352 690-691            V353 692-693            V354 694-695
        V355 696-697            V356 698-699            V357 700-701
        V358 702-703            V359 704-705            V360 706-707
        V361 708-709            V362 710-711            V363 712-713
        V364 714-715            V365 716-717            V366 718-719
        V367 720-721            V368 722-723            V369 724-725
        V370 726-727            V371 728-729            V372 730-731
        V373 732-733            V374 734-735            V375 736-737
        V376 738-740            V377 741-742            V378 743-744
        V379 745-746            V380 747-749            V381 750-751
        V382 752-753            V383 754-755            V384 756-758
        V385 759-760            V386 761-763            V387 764-765
        V388 766-768            V389 769-770            V390 771-772
        V391 773-774            V392 775-776            V393 777-778
        V394 779-781            V395 782-783            V396 784-785
        V397 786-787            V398 788-790            V399 791-792
        V400 793-795            V401 796-797            V402 798-800
        V403 801-802            V404 803-805            V405 806-807
        V406 808-810            V407 811-812            V408 813-814
        V409 815-816            V410 817-818            V411 819-820
        V412 821-822            V413 823-824            V414 825-827
        V415 828-829            V416 830-832            V417 833-834
        V418 835-837            V419 838-839            V420 840-842
        V421 843-844            V422 845-847            V423 848-849
        V424 850-852            V425 853-854            V426 855-856
        V427 857-858            V428 859-860            V429 861-862
        V430 863-864            V431 865-866            V432 867-868
        V433 869-870            V434 871-873            V435 874-875
        V436 876-878            V437 879-880            V438 881-883
        V439 884-885            V440 886-887            V441 888-889
        V442 890-891            V443 892-893            V444 894-895
        V445 896-897            V446 898-899            V447 900-901
        V448 902-904            V449 905-906            V450 907-908
        V451 909-910            V452 911-912            V453 913-914
        V454 915-917            V455 918-919            V456 920-921
        V457 922-923            V458 924-926            V459 927-928
        V460 929-931            V461 932-933            V462 934-935
        V463 936-937            V464 938-939            V465 940-941
        V466 942-943            V467 944-945            V468 946-947
        V469 948-949            V470 950-951            V471 952-953
        V472 954-955            V473 956-957            V474 958-959
        V475 960-961            V476 962-964            V477 965-966
        V478 967-968            V479 969-970            V480 971-972
        V481 973-974            V482 975-976            V483 977-978
        V484 979-980            V485 981-982            V486 983-984
        V487 985-986            V488 987-988            V489 989-990
        V490 991-992            V491 993-994            V492 995-997
        V493 998-999            V494 1000-1001          V495 1002-1003
        V496 1004-1005          V497 1006-1007          V498 1008-1009
        V499 1010-1011          V500 1012-1013          V501 1014-1015
        V502 1016-1017          V503 1018-1019          V504 1020-1021
        V505 1022-1023          V506 1024-1025          V507 1026-1027
        V508 1028-1030          V509 1031-1032          V510 1033-1034
        V511 1035-1036          V512 1037-1038          V513 1039-1040
        V514 1041-1042          V515 1043-1044          V516 1045-1046
        V517 1047-1048          V518 1049-1050          V519 1051-1052
        V520 1053-1054          V521 1055-1056          V522 1057-1058
        V523 1059-1060          V524 1061-1062          V525 1063-1064
        V526 1065-1066          V527 1067-1068          V528 1069-1070
        V529 1071-1073          V530 1074-1075          V531 1076-1077
        V532 1078-1079          V533 1080-1081          V534 1082-1083
        V535 1084-1085          V536 1086-1087          V537 1088-1089
        V538 1090-1091          V539 1092-1093          V540 1094-1095
        V541 1096-1097          V542 1098-1099          V543 1100-1101
        V544 1102-1103          V545 1104-1106          V546 1107-1108
        V547 1109-1110          V548 1111-1112          V549 1113-1114
        V550 1115-1116          V551 1117-1118          V552 1119-1120
        V553 1121-1122          V554 1123-1124          V555 1125-1126
        V556 1127-1128          V557 1129-1130          V558 1131-1132
        V559 1133-1134          V560 1135-1136          V561 1137-1139
        V562 1140-1141          V563 1142-1143          V564 1144-1145
        V565 1146-1147          V566 1148-1149          V567 1150-1151
        V568 1152-1153          V569 1154-1155          V570 1156-1157
        V571 1158-1159          V572 1160-1161          V573 1162-1163
        V574 1164-1165          V575 1166-1167          V576 1168-1169
        V577 1170-1171          V578 1172-1174          V579 1175-1176
        V580 1177-1178          V581 1179-1180          V582 1181-1182
        V583 1183-1184          V584 1185-1186          V585 1187-1188
        V586 1189-1190          V587 1191-1192          V588 1193-1194
        V589 1195-1196          V590 1197-1198          V591 1199-1200
        V592 1201-1202          V593 1203-1204          V594 1205-1206
        V595 1207-1209          V596 1210-1211          V597 1212-1213
        V598 1214-1215          V599 1216-1217          V600 1218-1219
        V601 1220-1221          V602 1222-1223          V603 1224-1225
        V604 1226-1227          V605 1228-1229          V606 1230-1231
        V607 1232-1233          V608 1234-1235          V609 1236-1237
        V610 1238-1239          V611 1240-1241          V612 1242-1243
        V613 1244-1245          V614 1246-1247          V615 1248-1249
        V616 1250-1251          V617 1252-1253          V618 1254-1255
        V619 1256-1257          V620 1258-1259          V621 1260-1261
        V622 1262-1263          V623 1264-1265          V624 1266-1267
        V625 1268-1269          V626 1270-1271          V627 1272-1273
        V628 1274-1275          V629 1276-1277          V630 1278-1279
        V631 1280-1281          V632 1282-1283          V633 1284-1285
        V634 1286-1287          V635 1288-1289          V636 1290-1291
        V637 1292-1293          V638 1294-1295          V639 1296-1297
        V640 1298-1299          V641 1300-1301          V642 1302-1304
        V643 1305-1306          V644 1307-1308          V645 1309-1310
        V646 1311-1312          V647 1313-1314          V648 1315-1316
        V649 1317-1318          V650 1319-1320          V651 1321-1322
        V652 1323-1324          V653 1325-1326          V654 1327-1328
        V655 1329-1330          V656 1331-1332          V657 1333-1334
        V658 1335-1336          V659 1337-1338          V660 1339-1340
        V661 1341-1342          V662 1343-1344          V663 1345-1346
        V664 1347-1348          V665 1349-1350          V666 1351-1352
        V667 1353-1354          V668 1355-1356          V669 1357-1358
        V670 1359-1360          V671 1361-1362          V672 1363-1364
        V673 1365-1366          V674 1367-1368          V675 1369-1370
        V676 1371-1372          V677 1373-1374          V678 1375-1376
        V679 1377-1378          V680 1379-1380          V681 1381-1382
        V682 1383-1384          V683 1385-1386          V684 1387-1388
        V685 1389-1390          V686 1391-1392          V687 1393-1394
        V688 1395-1396          V689 1397-1398          V690 1399-1400
        V691 1401-1402          V692 1403-1404          V693 1405-1406
        V694 1407-1409          V695 1410-1412          V696 1413-1415
        V697 1416-1417          V698 1418-1419          V699 1420-1421
        V700 1422-1423          V701 1424-1425          V702 1426-1427
        V703 1428-1429          V704 1430-1431          V705 1432-1433
        V706 1434-1435          V707 1436-1437          V708 1438-1439
        V709 1440-1441          V710 1442-1443          V711 1444-1445
        V712 1446-1447          V713 1448-1449          V714 1450-1451
        V715 1452-1453          V716 1454-1455          V717 1456-1457
        V718 1458-1459          V719 1460-1461          V720 1462-1463
        V721 1464-1465          V722 1466-1467          V723 1468-1469
        V724 1470-1471          V725 1472-1473          V726 1474-1475
        V727 1476-1477          V728 1478-1479          V729 1480-1481
        V730 1482-1483          V731 1484-1485          V732 1486-1487
        V733 1488-1489          V734 1490-1491          V735 1492-1493
        V736 1494-1495          V737 1496-1497          V738 1498-1499
        V739 1500-1501          V740 1502-1504          V741 1505-1507
        V742 1508-1509          V743 1510-1511          V744 1512-1513
        V745 1514-1515          V746 1516-1517          V747 1518-1519
        V748 1520-1521          V749 1522-1523          V750 1524-1525
        V751 1526-1527          V752 1528-1529          V753 1530-1531
        V754 1532-1533          V755 1534-1535          V756 1536-1537
        V757 1538-1539          V758 1540-1541          V759 1542-1543
        V760 1544-1546          V761 1547-1548          V762 1549-1550
        V763 1551-1552          V764 1553-1554          V765 1555-1556
        V766 1557-1558          V767 1559-1560          V768 1561-1562
        V769 1563-1564          V770 1565-1566          V771 1567-1569
        V772 1570-1571          V773 1572-1573          V774 1574-1575
        V775 1576-1578          V776 1579-1581          V777 1582-1584
        V778 1585-1586          V779 1587-1588          V780 1589-1590
        V781 1591-1592          V782 1593-1594          V783 1595-1596
        V784 1597-1598          V785 1599-1600          V786 1601-1602
        V787 1603-1604          V788 1605-1606          V789 1607-1608
        V790 1609-1610          V791 1611-1612          V792 1613-1614
        V793 1615-1616          V794 1617-1618          V795 1619-1620
        V796 1621-1622          V797 1623-1624          V798 1625-1626
        V799 1627-1628          ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'CASE IDENTIFICATION NUMBER'
   V5      = '1. SEX'
   V6      = '2. ETHNICITY'
   V10     = '4. AGE'
   V11     = '5. WITH WHOM LIVING'
   V12     = '6A1. EVENT-MARRIAGE'
   V13     = '6A2. WHEN-MONTH-MAR'
   V14     = '6A3. WHEN-YEAR-MAR'
   V15     = '6B1. EVENT-CHILDREN'
   V16     = '6B2. WHEN-MONTH-CHILD'
   V17     = '6B3. WHEN-YEAR-CHILD'
   V18     = '6C1. EVENT-SEPARATION'
   V19     = '6C2. WHEN-MONTH-SEP'
   V20     = '6C3. WHEN-YEAR-SEP'
   V21     = '6D1. EVENT-DIVORCE'
   V22     = '6D2. WHEN-MONTH-DIV'
   V23     = '6D3. WHEN-YEAR-DIV'
   V24     = '6E1. EVENT-REMARRIAGE'
   V25     = '6E2. WHEN-MONTH-REMAR'
   V26     = '6E3. WHEN-YEAR-REMAR'
   V27     = '7A1. PARENTS-DIVORCE'
   V28     = '7A2. 1ST DATE-MONTH-DIV'
   V29     = '7A3. 1ST DATE-YEAR-DIV'
   V30     = '7A4. 2ND DATE-MONTH-DIV'
   V31     = '7A5. 2ND DATE-YEAR-DIV'
   V32     = '7B1. PARENTS-SEPARATION'
   V33     = '7B2. 1ST DATE-MONTH-SEP'
   V34     = '7B3. 1ST DATE-YEAR-SEP'
   V35     = '7B4. 2ND DATE-MONTH-SEP'
   V36     = '7B5. 2ND DATE-YEAR-SEP'
   V37     = '7C1. PARENTS-REMARRIAGE'
   V38     = '7C2. 1ST DATE-MONTH'
   V39     = '7C3. 1ST DATE-YEAR'
   V40     = '7C4. 2ND DATE-MONTH'
   V41     = '7C5. 2ND DATE-YEAR'
   V42     = 'PSU NUMBER'
   V43     = 'FUNDING AGENCY DESIGN'
   V44     = 'HOUSEHOLD ID #'
   V45     = 'RESPONDENT ID #'
   V46     = 'DATA SET NUMBER'
   V47     = '7D1. PARENTS-DEATH'
   V48     = '7D2.1ST DATE-MONTH-DEATH'
   V49     = '7D3. 1ST DATE-YEAR-DEATH'
   V50     = '7D4.2ND DATE-MONTH-DEATH'
   V51     = '7D5.2ND DATE-YEAR-DEATH'
   V52     = '7E1.PAR-FATHER LOST JOB'
   V53     = '7E2.1ST DATE-MONTH-JOB-F'
   V54     = '7E3. 1ST DATE-YEAR-JOB-F'
   V55     = '7E4. 2ND DATE-MNTH-JOB-F'
   V56     = '7E5. 2ND DATE-YEAR-JOB-F'
   V57     = '7F1.PAR-MOTHER LOST JOB'
   V58     = '7F2. 1ST DATE-MNTH-JOB-M'
   V59     = '7F3. 1ST DATE-YEAR-JOB-M'
   V60     = '7F4. 2ND DATE-MNTH-JOB-M'
   V61     = '7F5. 2ND DATE-YEAR-JOB-M'
   V62     = '7G1. ADULT MOVED IN'
   V63     = '7G2. 1ST DATE-MONTH-IN'
   V64     = '7G3. 1ST DATE-YEAR-IN'
   V65     = '7G4. 2ND DATE-MONTH-IN'
   V66     = '7G5. 2ND DATE-YEAR-IN'
   V67     = '7H1. ADULT MOVED OUT'
   V68     = '7H2. 1ST DATE-MONTH-OUT'
   V69     = '7H3. 1ST DATE-YEAR-OUT'
   V70     = '7H4. 2ND DATE-MONTH-OUT'
   V71     = '7H5. 2ND DATE-YEAR-OUT'
   V72     = '7I. CODING PROBLEMS'
   V73     = '8.1 GRP/FRNDS LST YEAR'
   V74     = '8.2 CLOSE FRNDS LST YR'
   V75     = '9. IMPRTNCE/HAVING FRNDS'
   V76     = '11.#AFTERNOONS W/FRIENDS'
   V77     = '12. #EVENINGS W/FRIENDS'
   V78     = '13. WEEKENDS W/FRIENDS'
   V79     = '14. FRIENDS INFLUENCE'
   V80     = '15.HOW IMP HAVE FRIENDS'
   V81     = '16.EVENING/WEEK ON DATES'
   V82     = '17.IMPORT OF SOC ACTIV.'
   V83     = '18.ATTND SCHOOL PROGRAMS'
   V84     = '19. GRADE IN SCHOOL'
   V85     = '20. GRADE POINT AVERAGE'
   V86     = '21.# AFTERNOONS STUDYING'
   V87     = '22. # EVENINGS STUDYING'
   V88     = '23. # WEEKENDS STUDYING'
   V89     = '24.IMPRTNCE OF SCHOOLWRK'
   V90     = 'SOCIAL CLASS'
   V91     = '25.1 MEMBER/ATHLTIC TEAM'
   V92     = '25.2 TYPE/ATHLTIC TEAM'
   V93     = '26.IMPRTNCE OF ATHLETICS'
   V94     = '27.#AFTERNOONS W/TEAM'
   V95     = '28.#EVENINGS W/TEAM'
   V96     = '29.#WEEKENDS W/TEAM'
   V97     = '30.HOW IMP ARE ATHLETICS'
   V98     = '31.1 PRTCPATE/SCH ACTIV.'
   V99     = '31.2 TYPE OF ACTIVITY'
   V100    = '32.HOW IMP/SCHL ACTVTIES'
   V101    = '33.#AFTERNOONS W/ACTIVIT'
   V102    = '34.#EVENINGS W/ACTIVIT.'
   V103    = '35.WEEKENDS W/ACTIVIT.'
   V104    = '36.HOW IMP SCH ACTIVIT.'
   V105    = '37.HW CLASSMATES SEE R'
   V106    = '38.1 PRTCPATES COMM ACTV'
   V107    = '38.2 TYPE OF COMM ACTIV.'
   V108    = '39.IMP OF COMM ACTIVIT.'
   V109    = '40.#AFTERNOONS/COMM ACTS'
   V110    = '41.#EVES/COMM ACTIVITIES'
   V111    = '42.WKENDS/COMM ACTIVIT.'
   V112    = '43.HW IMP COMM ACTIVIT.'
   V113    = '44.ANY JOBS IN PAST YEAR'
   V114    = '45.IMPRTNCE/HAVING JOB'
   V115    = '46.1 JOB DESCRIPTION'
   V116    = '46.2 LENGTH/TIME ON JOB'
   V117    = '46.3 WHAT KIND OF WORK'
   V118    = '46.4 DUNCAN SOCIOEC INDX'
   V119    = '47. REASON FOR WORKING'
   V120    = '48.WAS JOB SUPERVISORY'
   V121    = '49.SPEND EXTRA TIME/JOB'
   V122    = '50.LIKE/STAY IN THIS WRK'
   V123    = '51.HW IMP HAS JOB BEEN'
   V124    = '52.#AFTERNOONS W/FAMILY'
   V125    = '53.#EVENINGS W/FAMILY'
   V126    = '54.WEEKENDS W/FAMILY'
   V127    = '55.IMPRTNCE OF FAM ACT.'
   V128    = '56.PARENTS INFLUENCE'
   V129    = '57.OFTN ATTND REL SRVCES'
   V130    = '58.HW IMP IS RELIGION'
   V131    = '59.1 IMP OF FAM ACTIVIT.'
   V132    = '59.2 FAM ACTIV.-HW DOING'
   V133    = '60.1 IMP-OTH STDNTS OPIN'
   V134    = '60.2 STDNTS OPIN-HW DOIN'
   V135    = '61.1 IMP-LOTS OF DATES'
   V136    = '61.2 LOTS/DATES-HW DOING'
   V137    = '62.1 IMP-TALK W/PARENTS'
   V138    = '62.2 TALK W/PARNTS-HW DO'
   V139    = '63.1 IMP-DO WELL ACADEM.'
   V140    = '63.2 WELL ACAD-HW DOING'
   V141    = '64.1 IMP-SOC W/FRIENDS'
   V142    = '64.2 SOC W/FRIENDS-HW DO'
   V143    = '65.1 IMP-COMFORT/PARENTS'
   V144    = '65.2 PRNTS COMFORT-HW DO'
   V145    = '66.1 IMP-SCH WRK/NO HELP'
   V146    = '66.2 SCHOOL/NO HLP-HW DO'
   V147    = '67.1 IMP-SPEC B/GFRIEND'
   V148    = '67.2 B/GFRIEND-HOW DOING'
   V149    = '68.1 IMP-PARENTS OPINION'
   V150    = '68.2 PARENTS OPIN-HW DO'
   V151    = '69.1 IMP-TEACHERS OPIN'
   V152    = '69.2 TEACH OPIN-HW DOING'
   V153    = '70.1IMP-FR ASK SPND TIME'
   V154    = '70.2FRND/SPND TIME-HW DO'
   V155    = '71.1 IMP-HI GRADE PT AVG'
   V156    = '71.2 HI GRADE PT-HW DOIN'
   V157    = '72.1 IMP-GET ALNG W/PARS'
   V158    = '72.2 ALNG W/PARNTS-HW DO'
   V159    = '73. IMPORTANCE/GOOD JOB'
   V160    = '74. IMPORTANCE/COLLEGE'
   V161    = '75. IMPORTANCE/MARRIAGE'
   V162    = '76. IMPORTNCE/CHILDREN'
   V163    = '77.1 JOB PLANS-SPECIFIC'
   V164    = '77A.JOB PLANS-CHANGING'
   V165    = '77B.PLANS-LOOK FOR INFOR'
   V166    = '77C.JOB PLANS-CONFUSION'
   V167    = '77D.PLNS-PARNTS DISAGREE'
   V168    = '77E.JOB PLANS-PLNS V PAR'
   V169    = '78.1 COLL PLNS-SPECIFIC'
   V170    = '78A.COLL PLNS-CHANGING'
   V171    = '78B.PLNS-LOOK FOR INFOR'
   V172    = '78C.COLL PLNS-CONFUSION'
   V173    = '78D.PLANS-PARNTS DISAGRE'
   V174    = '78E.PLNS-PLNS VS PARNTS'
   V175    = '79.1 MARR/CHIL-SPECIFIC'
   V176    = '79A.MARR/CHIL-CHANGING'
   V177    = '79B.M/CHL-LOOK FOR INFOR'
   V178    = '79C.MARR/CHIL-CONFUSION'
   V179    = '79D.M/CHL-PARNTS DISAGRE'
   V180    = '79E.M/CHL-PLNS VS PARNTS'
   V181    = '80.1 RELIGION-SPECIFIC'
   V182    = '80A.RELIGION-CHANGING'
   V183    = '80B.REL.-LOOK FOR INFOR'
   V184    = '80C.RELIGION-CONFUSION'
   V185    = '80D.REL.-PARENTS DISAGRE'
   V186    = '80E.REL.-PLNS VS PARENTS'
   V187    = '81.CHANCES-JOB YOU LIKE'
   V188    = '82.CHANCES-COMPLTNG COLL'
   V189    = '83.DONT FIT W/FRIENDS'
   V190    = '84.TEACH. DONT CALL ON'
   V191    = '85.FAMILY OUTSIDER'
   V192    = '86.NOBODY AT SCHOOL CARES'
   V193    = '87.FRIENDS NOT INTEREST'
   V194    = '88.FAM LISTENS/PROBLEMS'
   V195    = '89.FEEL CLOSE TO FRIENDS'
   V196    = '90.FEEL LONELY W/FAMILY'
   V197    = '91.DONT BELONG AT SCHOOL'
   V198    = '92.FRIENDS LISTEN PROBLM'
   V199    = '93.FEEL LONELY AT SCHOOL'
   V200    = '94.TCHRS DNT ASK/PROJCTS'
   V201    = '95.FEEL CLOSE TO FAMILY'
   V202    = '96.FEEL LONELY W/FRIENDS'
   V203    = '97.FAM NOT INTRSTED/PROB'
   V204    = '98.IMP HONEST W/PARENTS'
   V205    = '99.LIE TCHRS-AVOID TRBLE'
   V206    = '100.FRIENDS IMPRESN IMP'
   V207    = '101.PLAY DRTY TO WIN/SCL'
   V208    = '102.LYING FOR FRIENDS OK'
   V209    = '103.1ST IMPRESN IMP-PARS'
   V210    = '104.FIGHT KIDS/RESPECT'
   V211    = '105.SUCCEED W/O CHEATING'
   V212    = '106.BREAK RULES/POPULAR'
   V213    = '107.LIE PRNTS KEEP TRUST'
   V214    = '108.DOING OWN WORK/IMPOR'
   V215    = '109.BREAKING PARENT RULE'
   V216    = '110.GOOD IMP W/TEACHERS'
   V217    = '111.PRNTS AGRE-WELL LIKD'
   V218    = '112.PRNTS AGRE-NEED HELP'
   V219    = '113.PARENTS AGRE-BAD KID'
   V220    = '114.PRNTS AG-OFTEN UPSET'
   V221    = '115.PRNTS AG-GOOD CITIZN'
   V222    = '116.PARNTS AGRE-AMIABLE'
   V223    = '117.PRNTS AGRE-MESSED UP'
   V224    = '118.PRNTS AG-BREAK RULES'
   V225    = '119.PRNTS AG-PRSNL PROBS'
   V226    = '120.PRTS AG-GT INTO TRBL'
   V227    = '121.PRNTS AG-LKLY TO SUC'
   V228    = '122.PRNTS AG-BREAK LAWS'
   V229    = '123.FRNDS AG-WELL-LIKED'
   V230    = '124.FRNDS AGRE-NEED HELP'
   V231    = '125.FRNDS AGRE-BAD KID'
   V232    = '126.FRNDS AG-OFTEN UPSET'
   V233    = '127.FRNDS AGRE-AMIABLE'
   V234    = '128.FRNDS AGRE-MESSED UP'
   V235    = '129.FRNDS AG-BREAK RULES'
   V236    = '130.FRNDS AG-PRSNL PROBS'
   V237    = '131.FRNDS AG-GT IN TRBLE'
   V238    = '132.FRNDS AG-LIKLY SUCCD'
   V239    = '133.FRNDS AGRE-BREAK LAW'
   V240    = '134.TCHRS AGR-WELL-LIKED'
   V241    = '135.TCHRS AGRE-NEED HELP'
   V242    = '136.TCHRS AGRE-BAD KID'
   V243    = '137.TCHRS AG-OFTEN UPSET'
   V244    = '138.TCHRS AG-GOOD CITZEN'
   V245    = '139.TCHRS AGRE-AMIABLE'
   V246    = '140.TCHRS AGRE-MESSED UP'
   V247    = '141.TCHRS AG-BREAK RULES'
   V248    = '142.TCHRS AG-PERSNL PRBS'
   V249    = '143.TCHRS AG-GT IN TRBLE'
   V250    = '144.TCHRS AGR-LKLY SUCCD'
   V251    = '145.TCHRS AGR-BREAK LAWS'
   V252    = '146.P DSAPRV-KPT PROMISE'
   V253    = '147.PNTS DSAPRV-CHEATING'
   V254    = '148.PNTS DSAPRV-STEAL<$5'
   V255    = '149.PTS DSAPRV-OTHR RACE'
   V256    = '150.PS DSAPRV-SOLD DRUGS'
   V257    = '151.P DSAPRV-RTRND MONEY'
   V258    = '152.PTS DSAPRV-MARIJUANA'
   V259    = '153.PTS DSAPRV-STEAL>$50'
   V260    = '154.P DSAPRV-HIT SOMEONE'
   V261    = '155.PS DSAPRV-HELP NEEDY'
   V262    = '156.PRNTS DSAPRV-ALCOHOL'
   V263    = '157.PRNTS DSAPRV-A FAVOR'
   V264    = '158.P DSAPRV-DEST PROPTY'
   V265    = '159.P DSAPRV-LARCNY VHCL'
   V266    = '160.PEERS DSAPRV-PROMISE'
   V267    = '161.PEERS DSAPRV-CHEATED'
   V268    = '162.PEER DSAPRV-STEAL<$5'
   V269    = '163.PEER DSAPRV-DIF RACE'
   V270    = '164.PEER DSAPRV-SLD DRUG'
   V271    = '165.PEER DSAPRV-RETND $$'
   V272    = '166.PEER DSAPRV-MARIJUAN'
   V273    = '167.PEER DSAPRV-STLE>$50'
   V274    = '168.PEER DSAPRV-HIT SONE'
   V275    = '169.PEER DSAPRV-HLP NEDY'
   V276    = '170.PEERS DSAPRV-ALCOHOL'
   V277    = '171.PEER DSAPRV-A FAVOR'
   V278    = '172.PEER DSAPRV-SEX PRES'
   V279    = '173.PEER DSAPRV-DES PROP'
   V280    = '174.PEER DSPRV-LRCNY VEH'
   V281    = '175.PEER DSPRV-SEX INTER'
   V282    = '176.1MTHR RECT-TRBLE/SCL'
   V283    = '176.2FTHR RECT-TRBLE/SCL'
   V284    = '176.3FRNDS RCT-TRBLE/SCH'
   V285    = '177.1MTHR RCT-TRBL/POLCE'
   V286    = '177.2FTHR RCT-TRBL/POLCE'
   V287    = '177.3FRNDS RCT-TRB/POLCE'
   V288    = '178.1MTHR RCT-TRBL NBRHD'
   V289    = '178.2FTHR RCT-TRBL NBRHD'
   V290    = '178.3FRNDS RCT-TRB NBRHD'
   V291    = '179.1MTHR REACTN-W/RUMOR'
   V292    = '179.2FTHR REACTN-W/RUMOR'
   V293    = '179.3FRNDS REACT-W/RUMOR'
   V294    = '180.R- ATT:CHEAT SCL/TST'
   V295    = '181.R - ATT:DESTY PROPTY'
   V296    = '182.R - ATT:USE MARIJUAN'
   V297    = '183.R - ATT:STEAL < $5'
   V298    = '184.R - ATT:HIT SOMEONE'
   V299    = '185.R - ATT:USE ALCOHOL'
   V300    = '186.R - ATT:BRK IN VEHCL'
   V301    = '187.R- ATT:SELL HRD DRGS'
   V302    = '188.R- ATT:STEAL > $50'
   V303    = '189.R- ATT:GET DRUNK'
   V304    = '190.R ATT:USE PRESC DRGS'
   V305    = '191.R ATT:GIV/SELL ALCHL'
   V306    = '192.R- FRNDS:CHEAT/SCHL'
   V307    = '193.R- FRND:DEST PROPTY'
   V308    = '194.R- FRNDS:USE MARIJ'
   V309    = '195.R- FRNDS:STEAL <$5'
   V310    = '196.R- FRNDS:HIT SOMEONE'
   V311    = '197.R- FRNDS:USE ALCHOL'
   V312    = '198.R- FRNDS:BRK IN VEH'
   V313    = '199.R FRNDS:SLL HRD DRGS'
   V314    = '200.R- FRNDS:STEAL >$50'
   V315    = '201.R FDS:SUGGST BRK LAW'
   V316    = '202.R- FRNDS:GET DRUNK'
   V317    = '203.R- FRNDS:PRESC DRGS'
   V318    = '204.R FRDS:GVE/SLL ALCHL'
   V319    = '205.DEV FRNDS-CONT ASSOC'
   V320    = '206.DEV FRNDS-ST ACTVTES'
   V321    = '207.DEV FRNDS-LIE FR THM'
   V322    = '208.R AGRE-FA GRTR AUTHY'
   V323    = '209.R AGR-WOMN/MOST JOBS'
   V324    = '210.R AGR-MEN MST RELBLE'
   V325    = '211.R AGR-WOMEN EMOTIONL'
   V326    = '212.R AGR-WOMEN SMART'
   V327    = '213.R AGR-MEN SHDNT CRY'
   V328    = '214.R AGR-WMN RESP/CHILD'
   V329    = '215.R AGR-MEN RESP/MONEY'
   V330    = '216.R AGR-WOMEN WEAK'
   V331    = '217.R AGR-AGGR WMN/UNFEM'
   V332    = '218.R AGR-BEAT SOMONE OK'
   V333    = '219.R AGR-FIGHTNG & PROB'
   V334    = '220.R AGRE-HIT ACCEPTBLE'
   V335    = '221.R AGRE-TV VIOL EFCTV'
   V336    = '222.R AGRE-NO RSN FR HIT'
   V337    = '223.R AGRE-RETALIATE/HIT'
   V338    = '224.R AGR-OK HIT SOMEONE'
   V339    = '225.R AGR-TIMES/NEC FGHT'
   V340    = '226.R AGR-FORC/TIMES NEC'
   V341    = '227.R AGRE-RAPIST VIOLNT'
   V342    = '228.R AGRE-WOMN WNT RAPE'
   V343    = '229.R AG-HTCHKRS WNT RAP'
   V344    = '230.R AG-MEN RAPE FR SEX'
   V345    = '231.R AG-WMN RESIST RAPE'
   V346    = '232.R AG-VCTM FEEL GUILT'
   V347    = '233.R AG-RAPISTS MENTAL'
   V348    = '234.R AG-WMN ASK FR RAPE'
   V349    = '235.R AG-WOMN NOT RAPED'
   V350    = '236.R AG-RAPISTS ANGRY'
   V351    = '237.R AG-WMN RESPBL RAPE'
   V352    = '238.FRNDS SUGG GO DRINKN'
   V353    = '239.FRNDS PRESURE/DRINK'
   V354    = '240.FRNDS SUGG GET DRUNK'
   V355    = '241.FRNDS OFFER MARIJUAN'
   V356    = '242.FRNDS SUGG GET HIGH'
   V357    = '243.FRNDS PRESS US DRUGS'
   V358    = '244.1HW OFT FA USD ALCHL'
   V359    = '244.2HW OFT MO USD ALCHL'
   V360    = '245.1HW OFT FA GOT DRUNK'
   V361    = '245.2HW OFT MO GOT DRUNK'
   V362    = '246.1HW OFT FA US MARIJA'
   V363    = '246.2HW OFT MO US MARIJA'
   V364    = '247.1HW OFTN FA/TRANQZRS'
   V365    = '247.2HW OFTN MO/TRANQZRS'
   V366    = '248.1FRQ-DMG FAM PROPTY'
   V367    = '248.2RATE-DMG FAM PROPTY'
   V368    = '249.1FRQ-DMG SCHL PROPTY'
   V369    = '249.2RATE-DMG SCL PROPTY'
   V370    = '250.1FRQ-DMG OTHR PROPTY'
   V371    = '250.2RATE-DMG OTH PROPTY'
   V372    = '251.1FRQ -STLN MOTR VEHL'
   V373    = '251.2RATE-STLN MOTR VEHL'
   V374    = '252.1FRQNCY-STOLEN > $50'
   V375    = '252.2RATE-STOLEN > $50'
   V376    = '253.1FRQ-BGHT STOLEN GDS'
   V377    = '253.2RATE-BGHT STOLN GDS'
   V378    = '254.1FRQ -RETURN THINGS'
   V379    = '254.2RATE-RETURN  THINGS'
   V380    = '255.1FRQ -THROWN OBJECTS'
   V381    = '255.2RATE-THROWN OBJECTS'
   V382    = '256.1FRQ-RUNAWAY HOME'
   V383    = '256.2RATE-RUNAWAY/HOME'
   V384    = '257.1FRQNCY-LIED ABT AGE'
   V385    = '257.2RATE-LIED ABT AGE'
   V386    = '258.1FRQNCY-CARRY WEAPON'
   V387    = '258.2RATE-CARRIED WEAPON'
   V388    = '259.1FRQNCY-STOLEN < $5'
   V389    = '259.2RATE-STOLEN < $5'
   V390    = '260.1FRQ-ATTCKD SOMEONE'
   V391    = '260.2RATE-ATTCKD SOMEONE'
   V392    = '261.1FRQNCY-PAID SEX REL'
   V393    = '261.2RATE-PAID SEX RELS'
   V394    = '262.1FRQNCY-SEX INTRCRSE'
   V395    = '262.2RATE-SEX INTRCOURSE'
   V396    = '263.1FRQNCY-GANG FIGHTS'
   V397    = '263.2RATE-GANG FIGHTS'
   V398    = '264.1FRQNCY-SOLD MARIJUA'
   V399    = '264.2RATE-SOLD MARIJUANA'
   V400    = '265.1FRQNCY-CHEATED/TEST'
   V401    = '265.2RATE-CHEATED/TESTS'
   V402    = '266.1FRQ-HTCHHKD ILLEGLY'
   V403    = '266.2RATE-HTCHHK ILLEGLY'
   V404    = '267.1FRQ-HLP SOMONE HURT'
   V405    = '267.2RATE-HLP SOMONE HRT'
   V406    = '268.1FRQ-STLN MONEY FMLY'
   V407    = '268.2RATE-STLN MONY FMLY'
   V408    = '269.1FRQ-FORCED/HVE SEX'
   V409    = '269.2RATE-FORCED/HVE SEX'
   V410    = '270.1FRQNCY-HIT TEACHER'
   V411    = '270.2RATE-HIT TEACHER'
   V412    = '271.1FRQNCY-HIT PARENT'
   V413    = '271.2RATE-HIT PARENT'
   V414    = '272.1FRQ-HIT OTH STUDENT'
   V415    = '272.2RATE-HIT OTH STUDNT'
   V416    = '273.1FRQ-LOUD AND ROWDY'
   V417    = '273.2RATE-LOUD AND ROWDY'
   V418    = '274.1FRQ-SOLD HARD DRUGS'
   V419    = '274.2RATE-SOLD HARD DRUG'
   V420    = '275.1FRQ-TAKEN VEHICLE'
   V421    = '275.2RATE-TAKEN VEHICLE'
   V422    = '276.1FRQ-BOUGHT LIQUOR'
   V423    = '276.2RATE-BOUGHT LIQUOR'
   V424    = '277.1FRQ-GIVE MONEY,GOOD'
   V425    = '277.2RATE-GIV MONEY/GOOD'
   V426    = '278.1FRQ-PRSS SOMONE SEX'
   V427    = '278.2RATE-PRS SOMONE SEX'
   V428    = '279.1FRQ-USD FRCE/ STDNT'
   V429    = '279.2RATE-USD FRCE/STDNT'
   V430    = '280.1FRQ-USD FRCE/ TCHRS'
   V431    = '280.2RATE-USD FRCE/TCHRS'
   V432    = '281.1FRQ-REFSD HLP CHEAT'
   V433    = '281.2RATE-REFUSD/HLP CHT'
   V434    = '282.1FRQ-USD FRCE/ OTHRS'
   V435    = '282.2RATE-USD FRCE/OTHRS'
   V436    = '283.1FRQ-AVOIDED PAYING'
   V437    = '283.2RATE-AVOIDED PAYING'
   V438    = '284.1FRQ-BEEN DRUNK'
   V439    = '284.2RATE-BEEN DRUNK'
   V440    = '285.1FRQ-STOLEN $5-$50'
   V441    = '285.2RATE-STOLEN $5-$50'
   V442    = '286.1FRQ-STOLN AT SCHOOL'
   V443    = '286.2RATE-STOLN/ SCHOOL'
   V444    = '287.1FRQ-BROKEN INT BLDG'
   V445    = '287.2RATE-BROKN INT BLDG'
   V446    = '288.1FRQ-BEGGD FOR MONEY'
   V447    = '288.2RATE-BEGGD FR MONEY'
   V448    = '289.1FRQ-SKIPPED CLASSES'
   V449    = '289.2RATE-SKIPPED CLASS'
   V450    = '290.1FRQ-NOT RTRN CHANGE'
   V451    = '290.2RATE-NOT RTRN CHANG'
   V452    = '291.1FRQ-AGGRSV SEX DMND'
   V453    = '291.2RATE-AGRSV SEX DMND'
   V454    = '292.1FRQ-TLK FRNDS/ILLGL'
   V455    = '292.2RATE-TLK /ILLGL ACT'
   V456    = '293.1FRQ-BEEN SUSPENDED'
   V457    = '293.2RATE-BEEN SUSPENDED'
   V458    = '294.1FRQ-MDE OBSCEN CALL'
   V459    = '294.2RATE-MD OBSCEN CALL'
   V460    = '295.01BR-# TIMES/PAST YR'
   V461    = '295.02BR-DRINK NEXT YEAR'
   V462    = '295.03BR-HW OFTEN/PST YR'
   V463    = '295.04BR-EPISODIC USAGE'
   V464    = '295.05BR-LAST USED BEER'
   V465    = '295.06BR-HW MUCH WAS USD'
   V466    = '295.07BR-FUNCTION/ BEER'
   V467    = '295.08BR-HOW EFFCTIVE'
   V468    = '295.09SRCE/BR-FOOD STORE'
   V469    = '295.10SCE/BER-LIQ STORES'
   V470    = '295.11SRCE/BEER-FAMILY'
   V471    = '295.12SRCE/BEER-FRIENDS'
   V472    = '295.13SRCE/BR-RESTNT/BAR'
   V473    = '295.14SOURCE/BEER-OTHER'
   V474    = '295.15HVE STOPPD DRNK BR'
   V475    = '295.16WHY STOPPD DRNK BR'
   V476    = '296.01WIN-# TIMES/PST YR'
   V477    = '296.02WIN-DRINK NEXT YER'
   V478    = '296.03WIN-HW OFTN/PST YR'
   V479    = '296.04WIN-EPISODIC USAGE'
   V480    = '296.05WIN-LAST USED WINE'
   V481    = '296.06WIN-HW MCH WIN USD'
   V482    = '296.07WIN-FUNCTION/ WINE'
   V483    = '296.08WIN-HOW EFFCTIVE'
   V484    = '296.09SOURCE/FOOD STORE'
   V485    = '296.10SOURCE/LIQ STORES'
   V486    = '296.11SOURCE/WINE-FAMILY'
   V487    = '296.12SOURCE/WINE-FRIEND'
   V488    = '296.13SOURCE/RESTRNT/BAR'
   V489    = '296.14SOURCE/WINE-OTHER'
   V490    = '296.15HVE STPD DRNK WINE'
   V491    = '296.16WHY STPD DRNK WINE'
   V492    = '297.01LIQR-# TIME/PST YR'
   V493    = '297.02LIQR-DRINK NXT YER'
   V494    = '297.03LIQR-HW OFT/PST YR'
   V495    = '297.04LIQR-EPISODIC USAG'
   V496    = '297.05LIQ-LAST USED LIQR'
   V497    = '297.06LIQ-HOW MUCH/ USED'
   V498    = '297.07LIQ-FUNCTON/LIQUOR'
   V499    = '297.08LIQ-HOW EFFCTIVE'
   V500    = '297.09SRCE/LIQ-FOOD STRS'
   V501    = '297.10SRCE/LIQ-LIQ STORE'
   V502    = '297.11SOURCE/LIQ-FAMILY'
   V503    = '297.12SOURCE/LIQ-FRIENDS'
   V504    = '297.13SOURCE/RESTRNT/BAR'
   V505    = '297.14SOURCE/LIQ-OTHER'
   V506    = '297.15HVE STPD DRNK LIQR'
   V507    = '297.16WHY STOPD DRNK LIQ'
   V508    = '298.1ALCOH BEV-#TIMES/YR'
   V509    = '298.2ALCOH BEV-RATE/ USE'
   V510    = '299.01TBCO-USED/PST YEAR'
   V511    = '299.02TBCO-USE NEXT YEAR'
   V512    = '299.03TBCO-HW OFT/PST YR'
   V513    = '299.04TBCO-EPISODIC USAG'
   V514    = '299.05TBCO-LST USD TOBAC'
   V515    = '299.06#CIGS-USED PER DAY'
   V516    = '299.07#CIG/PIPES USD/DAY'
   V517    = '299.08#CANS CHEW/TBC/MTH'
   V518    = '299.09OTHER TOBACCO USAG'
   V519    = '299.10TBCO-FUNCT/TOBACCO'
   V520    = '299.11TBCO-HW EFFECTIVE'
   V521    = '299.12SRCE/TBC-STORE/GAS'
   V522    = '299.13SRCE/TBCO-CIG MACH'
   V523    = '299.14SOURCE/TBCO-FAMILY'
   V524    = '299.15SOURCE/TBCO-FRIEND'
   V525    = '299.16SOURCE/RESTRNT/BAR'
   V526    = '299.17SOURCE/TBCO-OTHER'
   V527    = '299.18HVE STOPPED/TOBACC'
   V528    = '299.19WHY STOPPED/TOBACC'
   V529    = '300.01MARJ-#TIMES PST/YR'
   V530    = '300.02MARIJ-USE NEXT YR'
   V531    = '300.03MARJ-HW OFT PST YR'
   V532    = '300.04MARIJ-EPISODIC USE'
   V533    = '300.05MARIJ-LAST USED'
   V534    = '300.06MARIJ-HW MUCH USED'
   V535    = '300.07MARIJ-FUNCTION'
   V536    = '300.08MARIJ-HW EFFECTIVE'
   V537    = '300.09SRCE/MARIJUANA-FAM'
   V538    = '300.10SRCE/MARIJ-FRIENDS'
   V539    = '300.11SRCE/MARIJ-ANONYMS'
   V540    = '300.12SRCE/MARIJANA-GROW'
   V541    = '300.13SRCE/MARIJNA-STEAL'
   V542    = '300.14SRCE/MARIJNA-OTHER'
   V543    = '300.15HVE STP USNG MARIJ'
   V544    = '300.16WHY STP USNG MARIJ'
   V545    = '301.01PSYCS-#TIMES PT/YR'
   V546    = '301.02PSYCS-USE NEXT  YR'
   V547    = '301.03PSYCS-HW OFT PT YR'
   V548    = '301.04PSYCS-EPISODIC USE'
   V549    = '301.05PSYCS-LAST USED'
   V550    = '301.06PSYCS-HW MUCH USED'
   V551    = '301.07PSYCS-FUNCTION'
   V552    = '301.08PSYCS-HW EFFECTIVE'
   V553    = '301.09SRCE/PSYCS-PHYSICN'
   V554    = '301.10SRCE/PSYCS-FAMILY'
   V555    = '301.11SRCE/PSYCS-FRIENDS'
   V556    = '301.12SRCE/PSYCS-ANONYMS'
   V557    = '301.13SRCE/PSYCS-STEAL'
   V558    = '301.14SRCE/PSYCS-OTHER'
   V559    = '301.15HVE STP USNG PSYCS'
   V560    = '301.16WHY STP USNG PSYCS'
   V561    = '302.01TRANQ-#TIMES PT/YR'
   V562    = '302.02TRANQ-USE NEXT YR'
   V563    = '302.03TRANQ-HW OFT PT YR'
   V564    = '302.04TRANQ-EPISODIC USE'
   V565    = '302.05TRANQ-LAST USED'
   V566    = '302.06TRANQ-PRESCRIBED'
   V567    = '302.07TRANQ- AMT PRESCBD'
   V568    = '302.08TRANQ-FUNCTION'
   V569    = '302.09TRANQ-EFFECTIVENES'
   V570    = '302.10SRCE/TRANQ-PHARMCY'
   V571    = '302.11SRCE/TRANQ-PHYSICN'
   V572    = '302.12SRCE/TRANQ-FAMILY'
   V573    = '302.13SRCE/TRANQ-FRIENDS'
   V574    = '302.14SRCE/TRANQ-ANONYMS'
   V575    = '302.15SRCE/TRANQ-OTHER'
   V576    = '302.16HVE STP USNG TRANQ'
   V577    = '302.17WHY STP USNG TRANQ'
   V578    = '303.01AMPHT-#TIMES PT/YR'
   V579    = '303.02AMPHT-USE NEXT YR'
   V580    = '303.03AMPHT-HW OFT PT YR'
   V581    = '303.04AMPHT-EPISODIC USE'
   V582    = '303.05AMPHT-LAST USED'
   V583    = '303.06AMPHT-PRESCRIBED'
   V584    = '303.07AMPHT- AMT PRESCBD'
   V585    = '303.08AMPHT-FUNCTION'
   V586    = '303.09AMPHS-EFFECTIVNESS'
   V587    = '303.10SRCE/AMPHS-PHARMCY'
   V588    = '303.11SRCE/AMPHS-PHYSICN'
   V589    = '303.12SRCE/AMPHS-FAMILY'
   V590    = '303.13SRCE/AMPHS-FRIENDS'
   V591    = '303.14SRCE/AMPHS-ANONYMS'
   V592    = '303.15SRCE/AMPHS-OTHER'
   V593    = '303.16HVE STP USNG AMPHS'
   V594    = '303.17WHY STP USNG AMPHS'
   V595    = '304.01BARBS-#TIMES PT/YR'
   V596    = '304.02BARBS-USE NEXT YER'
   V597    = '304.03BARBS-HW OFT PT YR'
   V598    = '304.04BARBS-EPISODIC USE'
   V599    = '304.05BARBS-LAST USED'
   V600    = '304.06BARBS-PRESCRIBED'
   V601    = '304.07BARBS-AMT PRESCRBD'
   V602    = '304.08BARBS-FUNCTION'
   V603    = '304.09BARBS-EFFECTIVENES'
   V604    = '304.10SRCE/BARBS-PHARMCY'
   V605    = '304.11SRCE/BARBS-PHYSICN'
   V606    = '304.12SRCE/BARBS-FAMILY'
   V607    = '304.13SRCE/BARBS-FRIENDS'
   V608    = '304.14SRCE/BARBS-ANONYMS'
   V609    = '304.15SRCE/BARBS-OTHER'
   V610    = '304.16HVE STP USNG BARBS'
   V611    = '304.17WHY STP USNG BARBS'
   V612    = '305.01CODN-# TIMES PT/YR'
   V613    = '305.02CODN-USE NEXT YEAR'
   V614    = '305.03CODN-HW OFTN PT YR'
   V615    = '305.04CODN-EPISODIC USE'
   V616    = '305.05CODN-LAST USED'
   V617    = '305.06CODN-PRESCRIBED'
   V618    = '305.07CODN-AMT PRESCRBD'
   V619    = '305.08CODN-FUNCTION'
   V620    = '305.09CODN-EFFECTIVENESS'
   V621    = '305.10SRCE/CODN-PHARMACY'
   V622    = '305.11SRCE/CODN-PHYSICN'
   V623    = '305.12SRCE/CODN-FAMILY'
   V624    = '305.13SRCE/CODN-FRIENDS'
   V625    = '305.14SRCE/CODN-ANONYOMS'
   V626    = '305.15SRCE/CODEINE-OTHER'
   V627    = '305.16HVE STP USNG CODNE'
   V628    = '305.17WHY STP USNG CODNE'
   V629    = '306.01HERO-# TIMES PT/YR'
   V630    = '306.02HERO-USE NEXT YEAR'
   V631    = '306.03HERO-HOW OFT PT YR'
   V632    = '306.04HERO-EPISODIC USE'
   V633    = '306.05HERO-LAST USED'
   V634    = '306.06HERO-FUNCTION'
   V635    = '306.07HERO-EFFECTIVENESS'
   V636    = '306.08SRCE/HEROIN-FAMILY'
   V637    = '306.09SRCE/HEROIN-FRIEND'
   V638    = '306.10SRCE/HERO-ANONYMOU'
   V639    = '306.11SRCE/HEROIN-OTHER'
   V640    = '306.12HVE STPD USNG HERO'
   V641    = '306.13WHY STPD USNG HERO'
   V642    = '307.00CO-# TIMES PAST/YR'
   V643    = '307.01CO-USE NEXT YEAR'
   V644    = '307.02CO-HW OFTN PAST YR'
   V645    = '307.03CO-EPISODIC USE'
   V646    = '307.04COCAINE-LAST USED'
   V647    = '307.05C-HOW MUCH WAS USD'
   V648    = '307.06COFUNCTION'
   V649    = '307.07COEFFECTIVENESS'
   V650    = '307.08SRCE/COCINE-FAMILY'
   V651    = '307.09SRCE/COINE-FRIENDS'
   V652    = '307.10SRCE/CO-ANONYMOUS'
   V653    = '307.11SRCE/COCAINE-OTHER'
   V654    = '307.12HVE STPD USNG COCE'
   V655    = '307.13WHY STPD USNG CO'
   V656    = '308.00IN-# TIMES PAST/YR'
   V657    = '308.01IN-USE NEXT YEAR'
   V658    = '308.02IN-HW OFTN PAST YR'
   V659    = '308.03IN-EPISODIC USE'
   V660    = '308.04IN-LAST USED'
   V661    = '308.05IN-FUNCTION'
   V662    = '308.06IN-EFFECTIVENESS'
   V663    = '308.07SRCE/IN-STORES'
   V664    = '308.08SRCE/IN-FAMILY'
   V665    = '308.09SRCE/IN-FRIENDS'
   V666    = '308.10SRCE/IN-OTHER'
   V667    = '308.11HVE STPD USNG IN'
   V668    = '308.12WHY STPD USNG IN'
   V669    = '309.00A D-#TIMES PAST/YR'
   V670    = '309.01A D-USE NEXT YEAR'
   V671    = '309.02A D-HW OFTN PST YR'
   V672    = '309.03A D-EPISODIC USE'
   V673    = '309.04A D-LAST USED'
   V674    = '309.05A D-HW MCH WAS USD'
   V675    = '309.06A D-FUNCTION'
   V676    = '309.07A D-HW EFFECTIVE'
   V677    = '309.08SRCE/A D-FAMILY'
   V678    = '309.09SRCE/A D-FRIENDS'
   V679    = '309.10SRCE/A D-ANONYMOUS'
   V680    = '309.11SRCE/A D-OTHER'
   V681    = '309.12HVE STPD USNG A DT'
   V682    = '309.13WHY STPD USNG A DT'
   V683    = '310.00NN PREC DRS-U LS/Y'
   V684    = '310.01NN PRESC DRGS-FRQ'
   V685    = '310.02NN PRES-USE NXT YR'
   V686    = '310.03NN PRES-HW OFTN'
   V687    = '310.04NN PRES-EPISODIC'
   V688    = '310.05NN PRES-LAST USED'
   V689    = '310.06NN PRES-FUNCTION'
   V690    = '310.07NN PRES-HW EFFCTVE'
   V691    = '310.08SRCE/NN PRESC DRUG'
   V692    = '310.09STPD USING NN PRES'
   V693    = '310.10WHY STPD NN PRESC'
   V694    = '311.MONTHLY EXPEND-ALCHL'
   V695    = '312.MONTHLY EXPEND-TOBAC'
   V696    = '313.MONTHLY EXPEND-DRUGS'
   V697    = '314.1TRBLE B/GFRND-ALCHL'
   V698    = '314.2TRBLE B/GFRND-DRUGS'
   V699    = '315.1PROBS W/FAM-ALCOHOL'
   V700    = '315.2PROBS W/FAMILY-DRUG'
   V701    = '316.1TRBLE W/FRNDS-ALCOL'
   V702    = '316.2TRBLE W/FRNDS-DRUGS'
   V703    = '317.1TRBLE W/TCHERS-ALCO'
   V704    = '317.2TRBLE W/TCHERS-DRUG'
   V705    = '318.1FIGHTS BCAUSE ALCOH'
   V706    = '318.2FIGHTS BCAUSE DRUGS'
   V707    = '319.1HLTH PROBS-ALCOHOL'
   V708    = '319.2HLTH PROBS-DRUGS'
   V709    = '320.1MEMORY LOSS-ALOCHOL'
   V710    = '320.2MEMORY LOSS-DRUGS'
   V711    = '321.1STAYED DRUNK/DAYS'
   V712    = '321.2STAYED HIGH/DAYS'
   V713    = '322.1CDNT STP ALCOL USE'
   V714    = '322.2CDNT STOP DRUG USE'
   V715    = '323.1HD TO BORROW/ALCOHL'
   V716    = '323.2HD TO BORROW/DRUGS'
   V717    = '324.1GO W/O FOR ALCOHOL'
   V718    = '324.2GO WITHOUT FR DRUGS'
   V719    = '325.01ILLEGAL ACT/ALCOHL'
   V720    = '325.02ILLEGAL ACTS/DRUGS'
   V721    = '325.03ILLGL ACT-STEALING'
   V722    = '325.04ILLGL ACT-PROSTITU'
   V723    = '325.05ILLGL ACT-GAMBLING'
   V724    = '325.06ILLGL ACT-SELL D/A'
   V725    = '325.07ILLGL SELL STLN GD'
   V726    = '325.08ILLGL BEAT SOMEONE'
   V727    = '325.09ILLGL ACT-FAKE ID'
   V728    = '325.10ILLGL STEAL DR/ALC'
   V729    = '325.11ILLGL FAKE PRESCTN'
   V730    = '325.12ILLGL FAKE ILLNESS'
   V731    = '325.13ILLGL ACT-GREW POT'
   V732    = '326.01ARRESTS FOR ALCOHL'
   V733    = '326.02ARRESTS FOR DRUGS'
   V734    = '326.03ARRESTS-INTOXICATN'
   V735    = '326.04ARRESTS-DRUNK DRVG'
   V736    = '326.05ARRESTS-POSSN ALCL'
   V737    = '326.06ARRESTS-POSSN/DRUG'
   V738    = '326.07ARRESTS-SALE/DRUGS'
   V739    = '326.08ARRESTS-OTHER'
   V740    = '327.PST YR-# TIMES DRUNK'
   V741    = '328.PST YR-# TIMES HIGH'
   V742    = '329.VICTIM-HAD THNGS TKN'
   V743    = '330.1VICTIM-BEATN/PARNTS'
   V744    = '330.2VICTMIZE-FORCED SEX'
   V745    = '331.VICTM-CAR/BIKE STOLN'
   V746    = '332.VICTM-THNGS TKN:CAR'
   V747    = '333.VICTM-THNGS DAMAGED'
   V748    = '334.VICTM-THNGS STLN PUB'
   V749    = '335.VICTM-SEXUALLY ATCKD'
   V750    = '336.01VICTM-ATTCKD W/WPN'
   V751    = '336.02ATTACKED/BROTHER'
   V752    = '336.03ATTACKED/SISTER'
   V753    = '336.04ATTACKED/TEACHER'
   V754    = '336.05ATTACKED/STUDENT'
   V755    = '336.06ATTACKED/GANG'
   V756    = '336.07ATTACKED/OTH ADULT'
   V757    = '336.08ATTACKED/OTH YOUTH'
   V758    = '336.09ATTACKED/OTHER'
   V759    = '336.10ATTACK INVLVED SEX'
   V760    = '337.01BEATEN UP/OTHERS'
   V761    = '337.02BEATEN UP/BROTHER'
   V762    = '337.03BEATEN UP/SISTER'
   V763    = '337.04BEATEN UP/TEACHER'
   V764    = '337.05BEATEN UP/STUDENT'
   V765    = '337.06BEATEN UP/GANG'
   V766    = '337.07BEAT UP/OTHR ADULT'
   V767    = '337.08BEAT UP/OTHR YOUTH'
   V768    = '337.09BEATEN UP/OTHER'
   V769    = '337.10BEAT INVLV FRCD SX'
   V770    = '338.SEXUALLY PRESSURED'
   V771    = '339.POCKET PICKED'
   V772    = '387.FURTHER EXPLN OF ANS'
   V773    = '388.1UNCOMFRT QUES-DRUGS'
   V774    = '388.2UNCOMFRTBL QUES-SEX'
   V775    = '388.3SPECIFIC QUESTION #'
   V776    = '388.4SPECIFIC QUESTION #'
   V777    = '388.5SPECIFIC QUESTION #'
   V778    = '389.1ASK QUES AB FRIENDS'
   V779    = '389.2QUES AB DRGS/ALCHOL'
   V780    = '389.3ASK QUES AB FAMILY'
   V781    = '389.4ASK QUES AB ACTIVIT'
   V782    = '389.5ASK QUES AB SCHOOL'
   V783    = '389.6ASK AB OTHER THINGS'
   V784    = '390.GOOD/POOR UNDERSTAND'
   V785    = '1.R - ANXTY AB INTERVIEW'
   V786    = '2.R HOSTILE TOWRD INTRVW'
   V787    = '3.R - INTRST/ INTERVIEW'
   V788    = '4.1PROBS-DFCLTY W/LNGUAG'
   V789    = '4.2PROBS-DIFFCLTY W/QUES'
   V790    = '4.3PROBS-INTERRUPTIONS'
   V791    = '4.4PROBS-TEMP BREAK-OFF'
   V792    = '4.5PROBS-BREAKOFF'
   V793    = '4.6PROBS-OTHER'
   V794    = '5.R - ANXTY AF INTERVIEW'
   V795    = 'INTERVWER ADDNL COMMENTS'
   V796    = 'SMSA CODE'
   V797    = 'PLACE CODE'
   V798    = 'PLACE SIZE'
   V799    = 'URBAN-SUBURBAN-RURAL CDE'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (V5 = -1) THEN V5 = .;
   IF (V6 = -1) THEN V6 = .;
   IF (V10 = -1) THEN V10 = .;
   IF (V11 = -1) THEN V11 = .;
   IF (V12 = -1) THEN V12 = .;
   IF (V13 = -1) THEN V13 = .;
   IF (V14 = -1) THEN V14 = .;
   IF (V15 = -1) THEN V15 = .;
   IF (V16 = -1) THEN V16 = .;
   IF (V17 = -1) THEN V17 = .;
   IF (V18 = -1) THEN V18 = .;
   IF (V19 = -1) THEN V19 = .;
   IF (V20 = -1) THEN V20 = .;
   IF (V21 = -1) THEN V21 = .;
   IF (V22 = -1) THEN V22 = .;
   IF (V23 = -1) THEN V23 = .;
   IF (V24 = -1) THEN V24 = .;
   IF (V25 = -1) THEN V25 = .;
   IF (V26 = -1) THEN V26 = .;
   IF (V27 = -1) THEN V27 = .;
   IF (V28 = -1) THEN V28 = .;
   IF (V29 = -1) THEN V29 = .;
   IF (V30 = -1) THEN V30 = .;
   IF (V31 = -1) THEN V31 = .;
   IF (V32 = -1) THEN V32 = .;
   IF (V33 = -1) THEN V33 = .;
   IF (V34 = -1) THEN V34 = .;
   IF (V35 = -1) THEN V35 = .;
   IF (V36 = -1) THEN V36 = .;
   IF (V37 = -1) THEN V37 = .;
   IF (V38 = -1) THEN V38 = .;
   IF (V39 = -1) THEN V39 = .;
   IF (V40 = -1) THEN V40 = .;
   IF (V41 = -1) THEN V41 = .;
   IF (V42 = -1) THEN V42 = .;
   IF (V44 = -1) THEN V44 = .;
   IF (V46 = -1) THEN V46 = .;
   IF (V47 = -1) THEN V47 = .;
   IF (V48 = -1) THEN V48 = .;
   IF (V49 = -1) THEN V49 = .;
   IF (V50 = -1) THEN V50 = .;
   IF (V51 = -1) THEN V51 = .;
   IF (V52 = -1) THEN V52 = .;
   IF (V53 = -1) THEN V53 = .;
   IF (V54 = -1) THEN V54 = .;
   IF (V55 = -1) THEN V55 = .;
   IF (V56 = -1) THEN V56 = .;
   IF (V57 = -1) THEN V57 = .;
   IF (V58 = -1) THEN V58 = .;
   IF (V59 = -1) THEN V59 = .;
   IF (V60 = -1) THEN V60 = .;
   IF (V61 = -1) THEN V61 = .;
   IF (V62 = -1) THEN V62 = .;
   IF (V63 = -1) THEN V63 = .;
   IF (V64 = -1) THEN V64 = .;
   IF (V65 = -1) THEN V65 = .;
   IF (V66 = -1) THEN V66 = .;
   IF (V67 = -1) THEN V67 = .;
   IF (V68 = -1) THEN V68 = .;
   IF (V69 = -1) THEN V69 = .;
   IF (V70 = -1) THEN V70 = .;
   IF (V71 = -1) THEN V71 = .;
   IF (V72 = -1) THEN V72 = .;
   IF (V73 = -1) THEN V73 = .;
   IF (V74 = -1) THEN V74 = .;
   IF (V75 = -1) THEN V75 = .;
   IF (V76 = -1) THEN V76 = .;
   IF (V77 = -1) THEN V77 = .;
   IF (V78 = -1) THEN V78 = .;
   IF (V79 = -1) THEN V79 = .;
   IF (V80 = -1) THEN V80 = .;
   IF (V81 = -1) THEN V81 = .;
   IF (V82 = -1) THEN V82 = .;
   IF (V83 = -1) THEN V83 = .;
   IF (V84 = -1) THEN V84 = .;
   IF (V85 = -1) THEN V85 = .;
   IF (V86 = -1) THEN V86 = .;
   IF (V87 = -1) THEN V87 = .;
   IF (V88 = -1) THEN V88 = .;
   IF (V89 = -1) THEN V89 = .;
   IF (V90 = -1) THEN V90 = .;
   IF (V91 = -1) THEN V91 = .;
   IF (V92 = -1) THEN V92 = .;
   IF (V93 = -1) THEN V93 = .;
   IF (V94 = -1) THEN V94 = .;
   IF (V95 = -1) THEN V95 = .;
   IF (V96 = -1) THEN V96 = .;
   IF (V97 = -1) THEN V97 = .;
   IF (V98 = -1) THEN V98 = .;
   IF (V99 = -1) THEN V99 = .;
   IF (V100 = -1) THEN V100 = .;
   IF (V101 = -1) THEN V101 = .;
   IF (V102 = -1) THEN V102 = .;
   IF (V103 = -1) THEN V103 = .;
   IF (V104 = -1) THEN V104 = .;
   IF (V105 = -1) THEN V105 = .;
   IF (V106 = -1) THEN V106 = .;
   IF (V107 = -1) THEN V107 = .;
   IF (V108 = -1) THEN V108 = .;
   IF (V109 = -1) THEN V109 = .;
   IF (V110 = -1) THEN V110 = .;
   IF (V111 = -1) THEN V111 = .;
   IF (V112 = -1) THEN V112 = .;
   IF (V113 = -1) THEN V113 = .;
   IF (V114 = -1) THEN V114 = .;
   IF (V115 = -1) THEN V115 = .;
   IF (V116 = -1) THEN V116 = .;
   IF (V117 = -1) THEN V117 = .;
   IF (V118 = -1) THEN V118 = .;
   IF (V119 = -1) THEN V119 = .;
   IF (V120 = -1) THEN V120 = .;
   IF (V121 = -1) THEN V121 = .;
   IF (V122 = -1) THEN V122 = .;
   IF (V123 = -1) THEN V123 = .;
   IF (V124 = -1) THEN V124 = .;
   IF (V125 = -1) THEN V125 = .;
   IF (V126 = -1) THEN V126 = .;
   IF (V127 = -1) THEN V127 = .;
   IF (V128 = -1) THEN V128 = .;
   IF (V129 = -1) THEN V129 = .;
   IF (V130 = -1) THEN V130 = .;
   IF (V131 = -1) THEN V131 = .;
   IF (V132 = -1) THEN V132 = .;
   IF (V133 = -1) THEN V133 = .;
   IF (V134 = -1) THEN V134 = .;
   IF (V135 = -1) THEN V135 = .;
   IF (V136 = -1) THEN V136 = .;
   IF (V137 = -1) THEN V137 = .;
   IF (V138 = -1) THEN V138 = .;
   IF (V139 = -1) THEN V139 = .;
   IF (V140 = -1) THEN V140 = .;
   IF (V141 = -1) THEN V141 = .;
   IF (V142 = -1) THEN V142 = .;
   IF (V143 = -1) THEN V143 = .;
   IF (V144 = -1) THEN V144 = .;
   IF (V145 = -1) THEN V145 = .;
   IF (V146 = -1) THEN V146 = .;
   IF (V147 = -1) THEN V147 = .;
   IF (V148 = -1) THEN V148 = .;
   IF (V149 = -1) THEN V149 = .;
   IF (V150 = -1) THEN V150 = .;
   IF (V151 = -1) THEN V151 = .;
   IF (V152 = -1) THEN V152 = .;
   IF (V153 = -1) THEN V153 = .;
   IF (V154 = -1) THEN V154 = .;
   IF (V155 = -1) THEN V155 = .;
   IF (V156 = -1) THEN V156 = .;
   IF (V157 = -1) THEN V157 = .;
   IF (V158 = -1) THEN V158 = .;
   IF (V159 = -1) THEN V159 = .;
   IF (V160 = -1) THEN V160 = .;
   IF (V161 = -1) THEN V161 = .;
   IF (V162 = -1) THEN V162 = .;
   IF (V163 = -1) THEN V163 = .;
   IF (V164 = -1) THEN V164 = .;
   IF (V165 = -1) THEN V165 = .;
   IF (V166 = -1) THEN V166 = .;
   IF (V167 = -1) THEN V167 = .;
   IF (V168 = -1) THEN V168 = .;
   IF (V169 = -1) THEN V169 = .;
   IF (V170 = -1) THEN V170 = .;
   IF (V171 = -1) THEN V171 = .;
   IF (V172 = -1) THEN V172 = .;
   IF (V173 = -1) THEN V173 = .;
   IF (V174 = -1) THEN V174 = .;
   IF (V175 = -1) THEN V175 = .;
   IF (V176 = -1) THEN V176 = .;
   IF (V177 = -1) THEN V177 = .;
   IF (V178 = -1) THEN V178 = .;
   IF (V179 = -1) THEN V179 = .;
   IF (V180 = -1) THEN V180 = .;
   IF (V181 = -1) THEN V181 = .;
   IF (V182 = -1) THEN V182 = .;
   IF (V183 = -1) THEN V183 = .;
   IF (V184 = -1) THEN V184 = .;
   IF (V185 = -1) THEN V185 = .;
   IF (V186 = -1) THEN V186 = .;
   IF (V187 = -1) THEN V187 = .;
   IF (V188 = -1) THEN V188 = .;
   IF (V189 = -1) THEN V189 = .;
   IF (V190 = -1) THEN V190 = .;
   IF (V191 = -1) THEN V191 = .;
   IF (V192 = -1) THEN V192 = .;
   IF (V193 = -1) THEN V193 = .;
   IF (V194 = -1) THEN V194 = .;
   IF (V195 = -1) THEN V195 = .;
   IF (V196 = -1) THEN V196 = .;
   IF (V197 = -1) THEN V197 = .;
   IF (V198 = -1) THEN V198 = .;
   IF (V199 = -1) THEN V199 = .;
   IF (V200 = -1) THEN V200 = .;
   IF (V201 = -1) THEN V201 = .;
   IF (V202 = -1) THEN V202 = .;
   IF (V203 = -1) THEN V203 = .;
   IF (V204 = -1) THEN V204 = .;
   IF (V205 = -1) THEN V205 = .;
   IF (V206 = -1) THEN V206 = .;
   IF (V207 = -1) THEN V207 = .;
   IF (V208 = -1) THEN V208 = .;
   IF (V209 = -1) THEN V209 = .;
   IF (V210 = -1) THEN V210 = .;
   IF (V211 = -1) THEN V211 = .;
   IF (V212 = -1) THEN V212 = .;
   IF (V213 = -1) THEN V213 = .;
   IF (V214 = -1) THEN V214 = .;
   IF (V215 = -1) THEN V215 = .;
   IF (V216 = -1) THEN V216 = .;
   IF (V217 = -1) THEN V217 = .;
   IF (V218 = -1) THEN V218 = .;
   IF (V219 = -1) THEN V219 = .;
   IF (V220 = -1) THEN V220 = .;
   IF (V221 = -1) THEN V221 = .;
   IF (V222 = -1) THEN V222 = .;
   IF (V223 = -1) THEN V223 = .;
   IF (V224 = -1) THEN V224 = .;
   IF (V225 = -1) THEN V225 = .;
   IF (V226 = -1) THEN V226 = .;
   IF (V227 = -1) THEN V227 = .;
   IF (V228 = -1) THEN V228 = .;
   IF (V229 = -1) THEN V229 = .;
   IF (V230 = -1) THEN V230 = .;
   IF (V231 = -1) THEN V231 = .;
   IF (V232 = -1) THEN V232 = .;
   IF (V233 = -1) THEN V233 = .;
   IF (V234 = -1) THEN V234 = .;
   IF (V235 = -1) THEN V235 = .;
   IF (V236 = -1) THEN V236 = .;
   IF (V237 = -1) THEN V237 = .;
   IF (V238 = -1) THEN V238 = .;
   IF (V239 = -1) THEN V239 = .;
   IF (V240 = -1) THEN V240 = .;
   IF (V241 = -1) THEN V241 = .;
   IF (V242 = -1) THEN V242 = .;
   IF (V243 = -1) THEN V243 = .;
   IF (V244 = -1) THEN V244 = .;
   IF (V245 = -1) THEN V245 = .;
   IF (V246 = -1) THEN V246 = .;
   IF (V247 = -1) THEN V247 = .;
   IF (V248 = -1) THEN V248 = .;
   IF (V249 = -1) THEN V249 = .;
   IF (V250 = -1) THEN V250 = .;
   IF (V251 = -1) THEN V251 = .;
   IF (V252 = -1) THEN V252 = .;
   IF (V253 = -1) THEN V253 = .;
   IF (V254 = -1) THEN V254 = .;
   IF (V255 = -1) THEN V255 = .;
   IF (V256 = -1) THEN V256 = .;
   IF (V257 = -1) THEN V257 = .;
   IF (V258 = -1) THEN V258 = .;
   IF (V259 = -1) THEN V259 = .;
   IF (V260 = -1) THEN V260 = .;
   IF (V261 = -1) THEN V261 = .;
   IF (V262 = -1) THEN V262 = .;
   IF (V263 = -1) THEN V263 = .;
   IF (V264 = -1) THEN V264 = .;
   IF (V265 = -1) THEN V265 = .;
   IF (V266 = -1) THEN V266 = .;
   IF (V267 = -1) THEN V267 = .;
   IF (V268 = -1) THEN V268 = .;
   IF (V269 = -1) THEN V269 = .;
   IF (V270 = -1) THEN V270 = .;
   IF (V271 = -1) THEN V271 = .;
   IF (V272 = -1) THEN V272 = .;
   IF (V273 = -1) THEN V273 = .;
   IF (V274 = -1) THEN V274 = .;
   IF (V275 = -1) THEN V275 = .;
   IF (V276 = -1) THEN V276 = .;
   IF (V277 = -1) THEN V277 = .;
   IF (V278 = -1) THEN V278 = .;
   IF (V279 = -1) THEN V279 = .;
   IF (V280 = -1) THEN V280 = .;
   IF (V281 = -1) THEN V281 = .;
   IF (V282 = -1) THEN V282 = .;
   IF (V283 = -1) THEN V283 = .;
   IF (V284 = -1) THEN V284 = .;
   IF (V285 = -1) THEN V285 = .;
   IF (V286 = -1) THEN V286 = .;
   IF (V287 = -1) THEN V287 = .;
   IF (V288 = -1) THEN V288 = .;
   IF (V289 = -1) THEN V289 = .;
   IF (V290 = -1) THEN V290 = .;
   IF (V291 = -1) THEN V291 = .;
   IF (V292 = -1) THEN V292 = .;
   IF (V293 = -1) THEN V293 = .;
   IF (V294 = -1) THEN V294 = .;
   IF (V295 = -1) THEN V295 = .;
   IF (V296 = -1) THEN V296 = .;
   IF (V297 = -1) THEN V297 = .;
   IF (V298 = -1) THEN V298 = .;
   IF (V299 = -1) THEN V299 = .;
   IF (V300 = -1) THEN V300 = .;
   IF (V301 = -1) THEN V301 = .;
   IF (V302 = -1) THEN V302 = .;
   IF (V303 = -1) THEN V303 = .;
   IF (V304 = -1) THEN V304 = .;
   IF (V305 = -1) THEN V305 = .;
   IF (V306 = -1) THEN V306 = .;
   IF (V307 = -1) THEN V307 = .;
   IF (V308 = -1) THEN V308 = .;
   IF (V309 = -1) THEN V309 = .;
   IF (V310 = -1) THEN V310 = .;
   IF (V311 = -1) THEN V311 = .;
   IF (V312 = -1) THEN V312 = .;
   IF (V313 = -1) THEN V313 = .;
   IF (V314 = -1) THEN V314 = .;
   IF (V315 = -1) THEN V315 = .;
   IF (V316 = -1) THEN V316 = .;
   IF (V317 = -1) THEN V317 = .;
   IF (V318 = -1) THEN V318 = .;
   IF (V319 = -1) THEN V319 = .;
   IF (V320 = -1) THEN V320 = .;
   IF (V321 = -1) THEN V321 = .;
   IF (V322 = -1) THEN V322 = .;
   IF (V323 = -1) THEN V323 = .;
   IF (V324 = -1) THEN V324 = .;
   IF (V325 = -1) THEN V325 = .;
   IF (V326 = -1) THEN V326 = .;
   IF (V327 = -1) THEN V327 = .;
   IF (V328 = -1) THEN V328 = .;
   IF (V329 = -1) THEN V329 = .;
   IF (V330 = -1) THEN V330 = .;
   IF (V331 = -1) THEN V331 = .;
   IF (V332 = -1) THEN V332 = .;
   IF (V333 = -1) THEN V333 = .;
   IF (V334 = -1) THEN V334 = .;
   IF (V335 = -1) THEN V335 = .;
   IF (V336 = -1) THEN V336 = .;
   IF (V337 = -1) THEN V337 = .;
   IF (V338 = -1) THEN V338 = .;
   IF (V339 = -1) THEN V339 = .;
   IF (V340 = -1) THEN V340 = .;
   IF (V341 = -1) THEN V341 = .;
   IF (V342 = -1) THEN V342 = .;
   IF (V343 = -1) THEN V343 = .;
   IF (V344 = -1) THEN V344 = .;
   IF (V345 = -1) THEN V345 = .;
   IF (V346 = -1) THEN V346 = .;
   IF (V347 = -1) THEN V347 = .;
   IF (V348 = -1) THEN V348 = .;
   IF (V349 = -1) THEN V349 = .;
   IF (V350 = -1) THEN V350 = .;
   IF (V351 = -1) THEN V351 = .;
   IF (V352 = -1) THEN V352 = .;
   IF (V353 = -1) THEN V353 = .;
   IF (V354 = -1) THEN V354 = .;
   IF (V355 = -1) THEN V355 = .;
   IF (V356 = -1) THEN V356 = .;
   IF (V357 = -1) THEN V357 = .;
   IF (V358 = -1) THEN V358 = .;
   IF (V359 = -1) THEN V359 = .;
   IF (V360 = -1) THEN V360 = .;
   IF (V361 = -1) THEN V361 = .;
   IF (V362 = -1) THEN V362 = .;
   IF (V363 = -1) THEN V363 = .;
   IF (V364 = -1) THEN V364 = .;
   IF (V365 = -1) THEN V365 = .;
   IF (V366 = -1) THEN V366 = .;
   IF (V367 = -1) THEN V367 = .;
   IF (V368 = -1) THEN V368 = .;
   IF (V369 = -1) THEN V369 = .;
   IF (V370 = -1) THEN V370 = .;
   IF (V371 = -1) THEN V371 = .;
   IF (V372 = -1) THEN V372 = .;
   IF (V373 = -1) THEN V373 = .;
   IF (V374 = -1) THEN V374 = .;
   IF (V375 = -1) THEN V375 = .;
   IF (V376 = -1) THEN V376 = .;
   IF (V377 = -1) THEN V377 = .;
   IF (V378 = -1) THEN V378 = .;
   IF (V379 = -1) THEN V379 = .;
   IF (V380 = -1) THEN V380 = .;
   IF (V381 = -1) THEN V381 = .;
   IF (V382 = -1) THEN V382 = .;
   IF (V383 = -1) THEN V383 = .;
   IF (V384 = -1) THEN V384 = .;
   IF (V385 = -1) THEN V385 = .;
   IF (V386 = -1) THEN V386 = .;
   IF (V387 = -1) THEN V387 = .;
   IF (V388 = -1) THEN V388 = .;
   IF (V389 = -1) THEN V389 = .;
   IF (V390 = -1) THEN V390 = .;
   IF (V391 = -1) THEN V391 = .;
   IF (V392 = -1) THEN V392 = .;
   IF (V393 = -1) THEN V393 = .;
   IF (V394 = -1) THEN V394 = .;
   IF (V395 = -1) THEN V395 = .;
   IF (V396 = -1) THEN V396 = .;
   IF (V397 = -1) THEN V397 = .;
   IF (V398 = -1) THEN V398 = .;
   IF (V399 = -1) THEN V399 = .;
   IF (V400 = -1) THEN V400 = .;
   IF (V401 = -1) THEN V401 = .;
   IF (V402 = -1) THEN V402 = .;
   IF (V403 = -1) THEN V403 = .;
   IF (V404 = -1) THEN V404 = .;
   IF (V405 = -1) THEN V405 = .;
   IF (V406 = -1) THEN V406 = .;
   IF (V407 = -1) THEN V407 = .;
   IF (V408 = -1) THEN V408 = .;
   IF (V409 = -1) THEN V409 = .;
   IF (V410 = -1) THEN V410 = .;
   IF (V411 = -1) THEN V411 = .;
   IF (V412 = -1) THEN V412 = .;
   IF (V413 = -1) THEN V413 = .;
   IF (V414 = -1) THEN V414 = .;
   IF (V415 = -1) THEN V415 = .;
   IF (V416 = -1) THEN V416 = .;
   IF (V417 = -1) THEN V417 = .;
   IF (V418 = -1) THEN V418 = .;
   IF (V419 = -1) THEN V419 = .;
   IF (V420 = -1) THEN V420 = .;
   IF (V421 = -1) THEN V421 = .;
   IF (V422 = -1) THEN V422 = .;
   IF (V423 = -1) THEN V423 = .;
   IF (V424 = -1) THEN V424 = .;
   IF (V425 = -1) THEN V425 = .;
   IF (V426 = -1) THEN V426 = .;
   IF (V427 = -1) THEN V427 = .;
   IF (V428 = -1) THEN V428 = .;
   IF (V429 = -1) THEN V429 = .;
   IF (V430 = -1) THEN V430 = .;
   IF (V431 = -1) THEN V431 = .;
   IF (V432 = -1) THEN V432 = .;
   IF (V433 = -1) THEN V433 = .;
   IF (V434 = -1) THEN V434 = .;
   IF (V435 = -1) THEN V435 = .;
   IF (V436 = -1) THEN V436 = .;
   IF (V437 = -1) THEN V437 = .;
   IF (V438 = -1) THEN V438 = .;
   IF (V439 = -1) THEN V439 = .;
   IF (V440 = -1) THEN V440 = .;
   IF (V441 = -1) THEN V441 = .;
   IF (V442 = -1) THEN V442 = .;
   IF (V443 = -1) THEN V443 = .;
   IF (V444 = -1) THEN V444 = .;
   IF (V445 = -1) THEN V445 = .;
   IF (V446 = -1) THEN V446 = .;
   IF (V447 = -1) THEN V447 = .;
   IF (V448 = -1) THEN V448 = .;
   IF (V449 = -1) THEN V449 = .;
   IF (V450 = -1) THEN V450 = .;
   IF (V451 = -1) THEN V451 = .;
   IF (V452 = -1) THEN V452 = .;
   IF (V453 = -1) THEN V453 = .;
   IF (V454 = -1) THEN V454 = .;
   IF (V455 = -1) THEN V455 = .;
   IF (V456 = -1) THEN V456 = .;
   IF (V457 = -1) THEN V457 = .;
   IF (V458 = -1) THEN V458 = .;
   IF (V459 = -1) THEN V459 = .;
   IF (V460 = -1) THEN V460 = .;
   IF (V461 = -1) THEN V461 = .;
   IF (V462 = -1) THEN V462 = .;
   IF (V463 = -1) THEN V463 = .;
   IF (V464 = -1) THEN V464 = .;
   IF (V465 = -1) THEN V465 = .;
   IF (V466 = -1) THEN V466 = .;
   IF (V467 = -1) THEN V467 = .;
   IF (V468 = -1) THEN V468 = .;
   IF (V469 = -1) THEN V469 = .;
   IF (V470 = -1) THEN V470 = .;
   IF (V471 = -1) THEN V471 = .;
   IF (V472 = -1) THEN V472 = .;
   IF (V473 = -1) THEN V473 = .;
   IF (V474 = -1) THEN V474 = .;
   IF (V475 = -1) THEN V475 = .;
   IF (V476 = -1) THEN V476 = .;
   IF (V477 = -1) THEN V477 = .;
   IF (V478 = -1) THEN V478 = .;
   IF (V479 = -1) THEN V479 = .;
   IF (V480 = -1) THEN V480 = .;
   IF (V481 = -1) THEN V481 = .;
   IF (V482 = -1) THEN V482 = .;
   IF (V483 = -1) THEN V483 = .;
   IF (V484 = -1) THEN V484 = .;
   IF (V485 = -1) THEN V485 = .;
   IF (V486 = -1) THEN V486 = .;
   IF (V487 = -1) THEN V487 = .;
   IF (V488 = -1) THEN V488 = .;
   IF (V489 = -1) THEN V489 = .;
   IF (V490 = -1) THEN V490 = .;
   IF (V491 = -1) THEN V491 = .;
   IF (V492 = -1) THEN V492 = .;
   IF (V493 = -1) THEN V493 = .;
   IF (V494 = -1) THEN V494 = .;
   IF (V495 = -1) THEN V495 = .;
   IF (V496 = -1) THEN V496 = .;
   IF (V497 = -1) THEN V497 = .;
   IF (V498 = -1) THEN V498 = .;
   IF (V499 = -1) THEN V499 = .;
   IF (V500 = -1) THEN V500 = .;
   IF (V501 = -1) THEN V501 = .;
   IF (V502 = -1) THEN V502 = .;
   IF (V503 = -1) THEN V503 = .;
   IF (V504 = -1) THEN V504 = .;
   IF (V505 = -1) THEN V505 = .;
   IF (V506 = -1) THEN V506 = .;
   IF (V507 = -1) THEN V507 = .;
   IF (V508 = -1) THEN V508 = .;
   IF (V509 = -1) THEN V509 = .;
   IF (V510 = -1) THEN V510 = .;
   IF (V511 = -1) THEN V511 = .;
   IF (V512 = -1) THEN V512 = .;
   IF (V513 = -1) THEN V513 = .;
   IF (V514 = -1) THEN V514 = .;
   IF (V515 = -1) THEN V515 = .;
   IF (V516 = -1) THEN V516 = .;
   IF (V517 = -1) THEN V517 = .;
   IF (V518 = -1) THEN V518 = .;
   IF (V519 = -1) THEN V519 = .;
   IF (V520 = -1) THEN V520 = .;
   IF (V521 = -1) THEN V521 = .;
   IF (V522 = -1) THEN V522 = .;
   IF (V523 = -1) THEN V523 = .;
   IF (V524 = -1) THEN V524 = .;
   IF (V525 = -1) THEN V525 = .;
   IF (V526 = -1) THEN V526 = .;
   IF (V527 = -1) THEN V527 = .;
   IF (V528 = -1) THEN V528 = .;
   IF (V529 = -1) THEN V529 = .;
   IF (V530 = -1) THEN V530 = .;
   IF (V531 = -1) THEN V531 = .;
   IF (V532 = -1) THEN V532 = .;
   IF (V533 = -1) THEN V533 = .;
   IF (V534 = -1) THEN V534 = .;
   IF (V535 = -1) THEN V535 = .;
   IF (V536 = -1) THEN V536 = .;
   IF (V537 = -1) THEN V537 = .;
   IF (V538 = -1) THEN V538 = .;
   IF (V539 = -1) THEN V539 = .;
   IF (V540 = -1) THEN V540 = .;
   IF (V541 = -1) THEN V541 = .;
   IF (V542 = -1) THEN V542 = .;
   IF (V543 = -1) THEN V543 = .;
   IF (V544 = -1) THEN V544 = .;
   IF (V545 = -1) THEN V545 = .;
   IF (V546 = -1) THEN V546 = .;
   IF (V547 = -1) THEN V547 = .;
   IF (V548 = -1) THEN V548 = .;
   IF (V549 = -1) THEN V549 = .;
   IF (V550 = -1) THEN V550 = .;
   IF (V551 = -1) THEN V551 = .;
   IF (V552 = -1) THEN V552 = .;
   IF (V553 = -1) THEN V553 = .;
   IF (V554 = -1) THEN V554 = .;
   IF (V555 = -1) THEN V555 = .;
   IF (V556 = -1) THEN V556 = .;
   IF (V557 = -1) THEN V557 = .;
   IF (V558 = -1) THEN V558 = .;
   IF (V559 = -1) THEN V559 = .;
   IF (V560 = -1) THEN V560 = .;
   IF (V561 = -1) THEN V561 = .;
   IF (V562 = -1) THEN V562 = .;
   IF (V563 = -1) THEN V563 = .;
   IF (V564 = -1) THEN V564 = .;
   IF (V565 = -1) THEN V565 = .;
   IF (V566 = -1) THEN V566 = .;
   IF (V567 = -1) THEN V567 = .;
   IF (V568 = -1) THEN V568 = .;
   IF (V569 = -1) THEN V569 = .;
   IF (V570 = -1) THEN V570 = .;
   IF (V571 = -1) THEN V571 = .;
   IF (V572 = -1) THEN V572 = .;
   IF (V573 = -1) THEN V573 = .;
   IF (V574 = -1) THEN V574 = .;
   IF (V575 = -1) THEN V575 = .;
   IF (V576 = -1) THEN V576 = .;
   IF (V577 = -1) THEN V577 = .;
   IF (V578 = -1) THEN V578 = .;
   IF (V579 = -1) THEN V579 = .;
   IF (V580 = -1) THEN V580 = .;
   IF (V581 = -1) THEN V581 = .;
   IF (V582 = -1) THEN V582 = .;
   IF (V583 = -1) THEN V583 = .;
   IF (V584 = -1) THEN V584 = .;
   IF (V585 = -1) THEN V585 = .;
   IF (V586 = -1) THEN V586 = .;
   IF (V587 = -1) THEN V587 = .;
   IF (V588 = -1) THEN V588 = .;
   IF (V589 = -1) THEN V589 = .;
   IF (V590 = -1) THEN V590 = .;
   IF (V591 = -1) THEN V591 = .;
   IF (V592 = -1) THEN V592 = .;
   IF (V593 = -1) THEN V593 = .;
   IF (V594 = -1) THEN V594 = .;
   IF (V595 = -1) THEN V595 = .;
   IF (V596 = -1) THEN V596 = .;
   IF (V597 = -1) THEN V597 = .;
   IF (V598 = -1) THEN V598 = .;
   IF (V599 = -1) THEN V599 = .;
   IF (V600 = -1) THEN V600 = .;
   IF (V601 = -1) THEN V601 = .;
   IF (V602 = -1) THEN V602 = .;
   IF (V603 = -1) THEN V603 = .;
   IF (V604 = -1) THEN V604 = .;
   IF (V605 = -1) THEN V605 = .;
   IF (V606 = -1) THEN V606 = .;
   IF (V607 = -1) THEN V607 = .;
   IF (V608 = -1) THEN V608 = .;
   IF (V609 = -1) THEN V609 = .;
   IF (V610 = -1) THEN V610 = .;
   IF (V611 = -1) THEN V611 = .;
   IF (V612 = -1) THEN V612 = .;
   IF (V613 = -1) THEN V613 = .;
   IF (V614 = -1) THEN V614 = .;
   IF (V615 = -1) THEN V615 = .;
   IF (V616 = -1) THEN V616 = .;
   IF (V617 = -1) THEN V617 = .;
   IF (V618 = -1) THEN V618 = .;
   IF (V619 = -1) THEN V619 = .;
   IF (V620 = -1) THEN V620 = .;
   IF (V621 = -1) THEN V621 = .;
   IF (V622 = -1) THEN V622 = .;
   IF (V623 = -1) THEN V623 = .;
   IF (V624 = -1) THEN V624 = .;
   IF (V625 = -1) THEN V625 = .;
   IF (V626 = -1) THEN V626 = .;
   IF (V627 = -1) THEN V627 = .;
   IF (V628 = -1) THEN V628 = .;
   IF (V629 = -1) THEN V629 = .;
   IF (V630 = -1) THEN V630 = .;
   IF (V631 = -1) THEN V631 = .;
   IF (V632 = -1) THEN V632 = .;
   IF (V633 = -1) THEN V633 = .;
   IF (V634 = -1) THEN V634 = .;
   IF (V635 = -1) THEN V635 = .;
   IF (V636 = -1) THEN V636 = .;
   IF (V637 = -1) THEN V637 = .;
   IF (V638 = -1) THEN V638 = .;
   IF (V639 = -1) THEN V639 = .;
   IF (V640 = -1) THEN V640 = .;
   IF (V641 = -1) THEN V641 = .;
   IF (V642 = -1) THEN V642 = .;
   IF (V643 = -1) THEN V643 = .;
   IF (V644 = -1) THEN V644 = .;
   IF (V645 = -1) THEN V645 = .;
   IF (V646 = -1) THEN V646 = .;
   IF (V647 = -1) THEN V647 = .;
   IF (V648 = -1) THEN V648 = .;
   IF (V649 = -1) THEN V649 = .;
   IF (V650 = -1) THEN V650 = .;
   IF (V651 = -1) THEN V651 = .;
   IF (V652 = -1) THEN V652 = .;
   IF (V653 = -1) THEN V653 = .;
   IF (V654 = -1) THEN V654 = .;
   IF (V655 = -1) THEN V655 = .;
   IF (V656 = -1) THEN V656 = .;
   IF (V657 = -1) THEN V657 = .;
   IF (V658 = -1) THEN V658 = .;
   IF (V659 = -1) THEN V659 = .;
   IF (V660 = -1) THEN V660 = .;
   IF (V661 = -1) THEN V661 = .;
   IF (V662 = -1) THEN V662 = .;
   IF (V663 = -1) THEN V663 = .;
   IF (V664 = -1) THEN V664 = .;
   IF (V665 = -1) THEN V665 = .;
   IF (V666 = -1) THEN V666 = .;
   IF (V667 = -1) THEN V667 = .;
   IF (V668 = -1) THEN V668 = .;
   IF (V669 = -1) THEN V669 = .;
   IF (V670 = -1) THEN V670 = .;
   IF (V671 = -1) THEN V671 = .;
   IF (V672 = -1) THEN V672 = .;
   IF (V673 = -1) THEN V673 = .;
   IF (V674 = -1) THEN V674 = .;
   IF (V675 = -1) THEN V675 = .;
   IF (V676 = -1) THEN V676 = .;
   IF (V677 = -1) THEN V677 = .;
   IF (V678 = -1) THEN V678 = .;
   IF (V679 = -1) THEN V679 = .;
   IF (V680 = -1) THEN V680 = .;
   IF (V681 = -1) THEN V681 = .;
   IF (V682 = -1) THEN V682 = .;
   IF (V683 = -1) THEN V683 = .;
   IF (V684 = -1) THEN V684 = .;
   IF (V685 = -1) THEN V685 = .;
   IF (V686 = -1) THEN V686 = .;
   IF (V687 = -1) THEN V687 = .;
   IF (V688 = -1) THEN V688 = .;
   IF (V689 = -1) THEN V689 = .;
   IF (V690 = -1) THEN V690 = .;
   IF (V691 = -1) THEN V691 = .;
   IF (V692 = -1) THEN V692 = .;
   IF (V693 = -1) THEN V693 = .;
   IF (V694 = -1) THEN V694 = .;
   IF (V695 = -1) THEN V695 = .;
   IF (V696 = -1) THEN V696 = .;
   IF (V697 = -1) THEN V697 = .;
   IF (V698 = -1) THEN V698 = .;
   IF (V699 = -1) THEN V699 = .;
   IF (V700 = -1) THEN V700 = .;
   IF (V701 = -1) THEN V701 = .;
   IF (V702 = -1) THEN V702 = .;
   IF (V703 = -1) THEN V703 = .;
   IF (V704 = -1) THEN V704 = .;
   IF (V705 = -1) THEN V705 = .;
   IF (V706 = -1) THEN V706 = .;
   IF (V707 = -1) THEN V707 = .;
   IF (V708 = -1) THEN V708 = .;
   IF (V709 = -1) THEN V709 = .;
   IF (V710 = -1) THEN V710 = .;
   IF (V711 = -1) THEN V711 = .;
   IF (V712 = -1) THEN V712 = .;
   IF (V713 = -1) THEN V713 = .;
   IF (V714 = -1) THEN V714 = .;
   IF (V715 = -1) THEN V715 = .;
   IF (V716 = -1) THEN V716 = .;
   IF (V717 = -1) THEN V717 = .;
   IF (V718 = -1) THEN V718 = .;
   IF (V719 = -1) THEN V719 = .;
   IF (V720 = -1) THEN V720 = .;
   IF (V721 = -1) THEN V721 = .;
   IF (V722 = -1) THEN V722 = .;
   IF (V723 = -1) THEN V723 = .;
   IF (V724 = -1) THEN V724 = .;
   IF (V725 = -1) THEN V725 = .;
   IF (V726 = -1) THEN V726 = .;
   IF (V727 = -1) THEN V727 = .;
   IF (V728 = -1) THEN V728 = .;
   IF (V729 = -1) THEN V729 = .;
   IF (V730 = -1) THEN V730 = .;
   IF (V731 = -1) THEN V731 = .;
   IF (V732 = -1) THEN V732 = .;
   IF (V733 = -1) THEN V733 = .;
   IF (V734 = -1) THEN V734 = .;
   IF (V735 = -1) THEN V735 = .;
   IF (V736 = -1) THEN V736 = .;
   IF (V737 = -1) THEN V737 = .;
   IF (V738 = -1) THEN V738 = .;
   IF (V739 = -1) THEN V739 = .;
   IF (V740 = -1) THEN V740 = .;
   IF (V741 = -1) THEN V741 = .;
   IF (V742 = -1) THEN V742 = .;
   IF (V743 = -1) THEN V743 = .;
   IF (V744 = -1) THEN V744 = .;
   IF (V745 = -1) THEN V745 = .;
   IF (V746 = -1) THEN V746 = .;
   IF (V747 = -1) THEN V747 = .;
   IF (V748 = -1) THEN V748 = .;
   IF (V749 = -1) THEN V749 = .;
   IF (V750 = -1) THEN V750 = .;
   IF (V751 = -1) THEN V751 = .;
   IF (V752 = -1) THEN V752 = .;
   IF (V753 = -1) THEN V753 = .;
   IF (V754 = -1) THEN V754 = .;
   IF (V755 = -1) THEN V755 = .;
   IF (V756 = -1) THEN V756 = .;
   IF (V757 = -1) THEN V757 = .;
   IF (V758 = -1) THEN V758 = .;
   IF (V759 = -1) THEN V759 = .;
   IF (V760 = -1) THEN V760 = .;
   IF (V761 = -1) THEN V761 = .;
   IF (V762 = -1) THEN V762 = .;
   IF (V763 = -1) THEN V763 = .;
   IF (V764 = -1) THEN V764 = .;
   IF (V765 = -1) THEN V765 = .;
   IF (V766 = -1) THEN V766 = .;
   IF (V767 = -1) THEN V767 = .;
   IF (V768 = -1) THEN V768 = .;
   IF (V769 = -1) THEN V769 = .;
   IF (V770 = -1) THEN V770 = .;
   IF (V771 = -1) THEN V771 = .;
   IF (V772 = -1) THEN V772 = .;
   IF (V773 = -1) THEN V773 = .;
   IF (V774 = -1) THEN V774 = .;
   IF (V775 = -1) THEN V775 = .;
   IF (V776 = -1) THEN V776 = .;
   IF (V777 = -1) THEN V777 = .;
   IF (V778 = -1) THEN V778 = .;
   IF (V779 = -1) THEN V779 = .;
   IF (V780 = -1) THEN V780 = .;
   IF (V781 = -1) THEN V781 = .;
   IF (V782 = -1) THEN V782 = .;
   IF (V783 = -1) THEN V783 = .;
   IF (V784 = -1) THEN V784 = .;
   IF (V785 = -1) THEN V785 = .;
   IF (V786 = -1) THEN V786 = .;
   IF (V787 = -1) THEN V787 = .;
   IF (V788 = -1) THEN V788 = .;
   IF (V789 = -1) THEN V789 = .;
   IF (V790 = -1) THEN V790 = .;
   IF (V791 = -1) THEN V791 = .;
   IF (V792 = -1) THEN V792 = .;
   IF (V793 = -1) THEN V793 = .;
   IF (V794 = -1) THEN V794 = .;
   IF (V795 = -1) THEN V795 = .;
   IF (V796 = -1) THEN V796 = .;
   IF (V797 = -1) THEN V797 = .;
   IF (V798 = -1) THEN V798 = .;
   IF (V799 = -1) THEN V799 = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT V5 v5ffffff. V6 v6ffffff. V11 v11fffff.
         V12 v12fffff. V13 v13fffff. V15 v15fffff.
         V16 v16fffff. V18 v18fffff. V19 v19fffff.
         V21 v21fffff. V22 v22fffff. V24 v24fffff.
         V25 v25fffff. V27 v27fffff. V28 v28fffff.
         V30 v30fffff. V32 v32fffff. V33 v33fffff.
         V35 v35fffff. V37 v37fffff. V38 v38fffff.
         V40 v40fffff. V43 v43fffff. V47 v47fffff.
         V48 v48fffff. V50 v50fffff. V52 v52fffff.
         V53 v53fffff. V55 v55fffff. V57 v57fffff.
         V58 v58fffff. V60 v60fffff. V62 v62fffff.
         V63 v63fffff. V65 v65fffff. V67 v67fffff.
         V68 v68fffff. V70 v70fffff. V72 v72fffff.
         V73 v73fffff. V74 v74fffff. V75 v75fffff.
         V76 v76fffff. V77 v77fffff. V78 v78fffff.
         V79 v79fffff. V80 v80fffff. V81 v81fffff.
         V82 v82fffff. V83 v83fffff. V84 v84fffff.
         V85 v85fffff. V86 v86fffff. V87 v87fffff.
         V88 v88fffff. V89 v89fffff. V91 v91fffff.
         V92 v92fffff. V93 v93fffff. V94 v94fffff.
         V95 v95fffff. V96 v96fffff. V97 v97fffff.
         V98 v98fffff. V99 v99fffff. V100 v100ffff.
         V101 v101ffff. V102 v102ffff. V103 v103ffff.
         V104 v104ffff. V105 v105ffff. V106 v106ffff.
         V107 v107ffff. V108 v108ffff. V109 v109ffff.
         V110 v110ffff. V111 v111ffff. V112 v112ffff.
         V113 v113ffff. V114 v114ffff. V115 v115ffff.
         V116 v116ffff. V117 v117ffff. V119 v119ffff.
         V120 v120ffff. V121 v121ffff. V122 v122ffff.
         V123 v123ffff. V124 v124ffff. V125 v125ffff.
         V126 v126ffff. V127 v127ffff. V128 v128ffff.
         V129 v129ffff. V130 v130ffff. V131 v131ffff.
         V132 v132ffff. V133 v133ffff. V134 v134ffff.
         V135 v135ffff. V136 v136ffff. V137 v137ffff.
         V138 v138ffff. V139 v139ffff. V140 v140ffff.
         V141 v141ffff. V142 v142ffff. V143 v143ffff.
         V144 v144ffff. V145 v145ffff. V146 v146ffff.
         V147 v147ffff. V148 v148ffff. V149 v149ffff.
         V150 v150ffff. V151 v151ffff. V152 v152ffff.
         V153 v153ffff. V154 v154ffff. V155 v155ffff.
         V156 v156ffff. V157 v157ffff. V158 v158ffff.
         V159 v159ffff. V160 v160ffff. V161 v161ffff.
         V162 v162ffff. V163 v163ffff. V164 v164ffff.
         V165 v165ffff. V166 v166ffff. V167 v167ffff.
         V168 v168ffff. V169 v169ffff. V170 v170ffff.
         V171 v171ffff. V172 v172ffff. V173 v173ffff.
         V174 v174ffff. V175 v175ffff. V176 v176ffff.
         V177 v177ffff. V178 v178ffff. V179 v179ffff.
         V180 v180ffff. V181 v181ffff. V182 v182ffff.
         V183 v183ffff. V184 v184ffff. V185 v185ffff.
         V186 v186ffff. V187 v187ffff. V188 v188ffff.
         V189 v189ffff. V190 v190ffff. V191 v191ffff.
         V192 v192ffff. V193 v193ffff. V194 v194ffff.
         V195 v195ffff. V196 v196ffff. V197 v197ffff.
         V198 v198ffff. V199 v199ffff. V200 v200ffff.
         V201 v201ffff. V202 v202ffff. V203 v203ffff.
         V204 v204ffff. V205 v205ffff. V206 v206ffff.
         V207 v207ffff. V208 v208ffff. V209 v209ffff.
         V210 v210ffff. V211 v211ffff. V212 v212ffff.
         V213 v213ffff. V214 v214ffff. V215 v215ffff.
         V216 v216ffff. V217 v217ffff. V218 v218ffff.
         V219 v219ffff. V220 v220ffff. V221 v221ffff.
         V222 v222ffff. V223 v223ffff. V224 v224ffff.
         V225 v225ffff. V226 v226ffff. V227 v227ffff.
         V228 v228ffff. V229 v229ffff. V230 v230ffff.
         V231 v231ffff. V232 v232ffff. V233 v233ffff.
         V234 v234ffff. V235 v235ffff. V236 v236ffff.
         V237 v237ffff. V238 v238ffff. V239 v239ffff.
         V240 v240ffff. V241 v241ffff. V242 v242ffff.
         V243 v243ffff. V244 v244ffff. V245 v245ffff.
         V246 v246ffff. V247 v247ffff. V248 v248ffff.
         V249 v249ffff. V250 v250ffff. V251 v251ffff.
         V252 v252ffff. V253 v253ffff. V254 v254ffff.
         V255 v255ffff. V256 v256ffff. V257 v257ffff.
         V258 v258ffff. V259 v259ffff. V260 v260ffff.
         V261 v261ffff. V262 v262ffff. V263 v263ffff.
         V264 v264ffff. V265 v265ffff. V266 v266ffff.
         V267 v267ffff. V268 v268ffff. V269 v269ffff.
         V270 v270ffff. V271 v271ffff. V272 v272ffff.
         V273 v273ffff. V274 v274ffff. V275 v275ffff.
         V276 v276ffff. V277 v277ffff. V278 v278ffff.
         V279 v279ffff. V280 v280ffff. V281 v281ffff.
         V282 v282ffff. V283 v283ffff. V284 v284ffff.
         V285 v285ffff. V286 v286ffff. V287 v287ffff.
         V288 v288ffff. V289 v289ffff. V290 v290ffff.
         V291 v291ffff. V292 v292ffff. V293 v293ffff.
         V294 v294ffff. V295 v295ffff. V296 v296ffff.
         V297 v297ffff. V298 v298ffff. V299 v299ffff.
         V300 v300ffff. V301 v301ffff. V302 v302ffff.
         V303 v303ffff. V304 v304ffff. V305 v305ffff.
         V306 v306ffff. V307 v307ffff. V308 v308ffff.
         V309 v309ffff. V310 v310ffff. V311 v311ffff.
         V312 v312ffff. V313 v313ffff. V314 v314ffff.
         V315 v315ffff. V316 v316ffff. V317 v317ffff.
         V318 v318ffff. V319 v319ffff. V320 v320ffff.
         V321 v321ffff. V322 v322ffff. V323 v323ffff.
         V324 v324ffff. V325 v325ffff. V326 v326ffff.
         V327 v327ffff. V328 v328ffff. V329 v329ffff.
         V330 v330ffff. V331 v331ffff. V332 v332ffff.
         V333 v333ffff. V334 v334ffff. V335 v335ffff.
         V336 v336ffff. V337 v337ffff. V338 v338ffff.
         V339 v339ffff. V340 v340ffff. V341 v341ffff.
         V342 v342ffff. V343 v343ffff. V344 v344ffff.
         V345 v345ffff. V346 v346ffff. V347 v347ffff.
         V348 v348ffff. V349 v349ffff. V350 v350ffff.
         V351 v351ffff. V352 v352ffff. V353 v353ffff.
         V354 v354ffff. V355 v355ffff. V356 v356ffff.
         V357 v357ffff. V358 v358ffff. V359 v359ffff.
         V360 v360ffff. V361 v361ffff. V362 v362ffff.
         V363 v363ffff. V364 v364ffff. V365 v365ffff.
         V367 v367ffff. V369 v369ffff. V371 v371ffff.
         V373 v373ffff. V375 v375ffff. V377 v377ffff.
         V379 v379ffff. V381 v381ffff. V383 v383ffff.
         V385 v385ffff. V387 v387ffff. V389 v389ffff.
         V391 v391ffff. V393 v393ffff. V395 v395ffff.
         V397 v397ffff. V399 v399ffff. V401 v401ffff.
         V403 v403ffff. V405 v405ffff. V407 v407ffff.
         V409 v409ffff. V411 v411ffff. V413 v413ffff.
         V415 v415ffff. V417 v417ffff. V419 v419ffff.
         V421 v421ffff. V423 v423ffff. V425 v425ffff.
         V427 v427ffff. V429 v429ffff. V431 v431ffff.
         V433 v433ffff. V435 v435ffff. V437 v437ffff.
         V439 v439ffff. V441 v441ffff. V443 v443ffff.
         V445 v445ffff. V447 v447ffff. V449 v449ffff.
         V451 v451ffff. V453 v453ffff. V455 v455ffff.
         V457 v457ffff. V459 v459ffff. V461 v461ffff.
         V462 v462ffff. V463 v463ffff. V465 v465ffff.
         V466 v466ffff. V467 v467ffff. V468 v468ffff.
         V469 v469ffff. V470 v470ffff. V471 v471ffff.
         V472 v472ffff. V473 v473ffff. V474 v474ffff.
         V475 v475ffff. V477 v477ffff. V478 v478ffff.
         V479 v479ffff. V481 v481ffff. V482 v482ffff.
         V483 v483ffff. V484 v484ffff. V485 v485ffff.
         V486 v486ffff. V487 v487ffff. V488 v488ffff.
         V489 v489ffff. V490 v490ffff. V491 v491ffff.
         V493 v493ffff. V494 v494ffff. V495 v495ffff.
         V497 v497ffff. V498 v498ffff. V499 v499ffff.
         V500 v500ffff. V501 v501ffff. V502 v502ffff.
         V503 v503ffff. V504 v504ffff. V505 v505ffff.
         V506 v506ffff. V507 v507ffff. V509 v509ffff.
         V510 v510ffff. V511 v511ffff. V512 v512ffff.
         V513 v513ffff. V519 v519ffff. V520 v520ffff.
         V521 v521ffff. V522 v522ffff. V523 v523ffff.
         V524 v524ffff. V525 v525ffff. V526 v526ffff.
         V527 v527ffff. V528 v528ffff. V530 v530ffff.
         V531 v531ffff. V532 v532ffff. V534 v534ffff.
         V535 v535ffff. V536 v536ffff. V537 v537ffff.
         V538 v538ffff. V539 v539ffff. V540 v540ffff.
         V541 v541ffff. V542 v542ffff. V543 v543ffff.
         V544 v544ffff. V546 v546ffff. V547 v547ffff.
         V548 v548ffff. V551 v551ffff. V552 v552ffff.
         V553 v553ffff. V554 v554ffff. V555 v555ffff.
         V556 v556ffff. V557 v557ffff. V558 v558ffff.
         V559 v559ffff. V560 v560ffff. V562 v562ffff.
         V563 v563ffff. V564 v564ffff. V566 v566ffff.
         V567 v567ffff. V568 v568ffff. V569 v569ffff.
         V570 v570ffff. V571 v571ffff. V572 v572ffff.
         V573 v573ffff. V574 v574ffff. V575 v575ffff.
         V576 v576ffff. V577 v577ffff. V579 v579ffff.
         V580 v580ffff. V581 v581ffff. V583 v583ffff.
         V584 v584ffff. V585 v585ffff. V586 v586ffff.
         V587 v587ffff. V588 v588ffff. V589 v589ffff.
         V590 v590ffff. V591 v591ffff. V592 v592ffff.
         V593 v593ffff. V594 v594ffff. V596 v596ffff.
         V597 v597ffff. V598 v598ffff. V600 v600ffff.
         V601 v601ffff. V602 v602ffff. V603 v603ffff.
         V604 v604ffff. V605 v605ffff. V606 v606ffff.
         V607 v607ffff. V608 v608ffff. V609 v609ffff.
         V610 v610ffff. V611 v611ffff. V613 v613ffff.
         V614 v614ffff. V615 v615ffff. V617 v617ffff.
         V618 v618ffff. V619 v619ffff. V620 v620ffff.
         V621 v621ffff. V622 v622ffff. V623 v623ffff.
         V624 v624ffff. V625 v625ffff. V626 v626ffff.
         V627 v627ffff. V628 v628ffff. V630 v630ffff.
         V631 v631ffff. V632 v632ffff. V634 v634ffff.
         V635 v635ffff. V636 v636ffff. V637 v637ffff.
         V638 v638ffff. V639 v639ffff. V640 v640ffff.
         V641 v641ffff. V643 v643ffff. V644 v644ffff.
         V645 v645ffff. V647 v647ffff. V648 v648ffff.
         V649 v649ffff. V650 v650ffff. V651 v651ffff.
         V652 v652ffff. V653 v653ffff. V654 v654ffff.
         V655 v655ffff. V657 v657ffff. V658 v658ffff.
         V659 v659ffff. V661 v661ffff. V662 v662ffff.
         V663 v663ffff. V664 v664ffff. V665 v665ffff.
         V666 v666ffff. V667 v667ffff. V668 v668ffff.
         V670 v670ffff. V671 v671ffff. V672 v672ffff.
         V674 v674ffff. V675 v675ffff. V676 v676ffff.
         V677 v677ffff. V678 v678ffff. V679 v679ffff.
         V680 v680ffff. V681 v681ffff. V682 v682ffff.
         V683 v683ffff. V685 v685ffff. V686 v686ffff.
         V687 v687ffff. V689 v689ffff. V690 v690ffff.
         V691 v691ffff. V692 v692ffff. V693 v693ffff.
         V697 v697ffff. V698 v698ffff. V699 v699ffff.
         V700 v700ffff. V701 v701ffff. V702 v702ffff.
         V703 v703ffff. V704 v704ffff. V705 v705ffff.
         V706 v706ffff. V707 v707ffff. V708 v708ffff.
         V709 v709ffff. V710 v710ffff. V711 v711ffff.
         V712 v712ffff. V713 v713ffff. V714 v714ffff.
         V715 v715ffff. V716 v716ffff. V717 v717ffff.
         V718 v718ffff. V719 v719ffff. V720 v720ffff.
         V721 v721ffff. V722 v722ffff. V723 v723ffff.
         V724 v724ffff. V725 v725ffff. V726 v726ffff.
         V727 v727ffff. V728 v728ffff. V729 v729ffff.
         V730 v730ffff. V731 v731ffff. V732 v732ffff.
         V733 v733ffff. V744 v744ffff. V751 v751ffff.
         V752 v752ffff. V753 v753ffff. V754 v754ffff.
         V755 v755ffff. V756 v756ffff. V757 v757ffff.
         V758 v758ffff. V759 v759ffff. V761 v761ffff.
         V762 v762ffff. V763 v763ffff. V764 v764ffff.
         V765 v765ffff. V766 v766ffff. V767 v767ffff.
         V768 v768ffff. V769 v769ffff. V772 v772ffff.
         V773 v773ffff. V774 v774ffff. V778 v778ffff.
         V779 v779ffff. V780 v780ffff. V781 v781ffff.
         V782 v782ffff. V783 v783ffff. V784 v784ffff.
         V785 v785ffff. V786 v786ffff. V787 v787ffff.
         V788 v788ffff. V789 v789ffff. V790 v790ffff.
         V791 v791ffff. V792 v792ffff. V793 v793ffff.
         V794 v794ffff. V795 v795ffff. V796 v796ffff.
         V797 v797ffff. V798 v798ffff. V799 v799ffff.
          ;
*/

RUN ;
